package cn.sino.mark.common.config;

import cn.sino.mark.common.constants.Constant;
import cn.sino.mark.common.utils.LoginUserUtil;
import com.baomidou.mybatisplus.annotation.DbType;
import com.baomidou.mybatisplus.autoconfigure.ConfigurationCustomizer;
import com.baomidou.mybatisplus.core.handlers.MetaObjectHandler;
import com.baomidou.mybatisplus.extension.plugins.MybatisPlusInterceptor;
import com.baomidou.mybatisplus.extension.plugins.inner.PaginationInnerInterceptor;
import org.apache.ibatis.reflection.MetaObject;
import org.mybatis.spring.annotation.MapperScan;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.jdbc.datasource.DataSourceTransactionManager;
import org.springframework.transaction.TransactionManager;

import javax.sql.DataSource;
import java.time.LocalDateTime;

@Configuration
@MapperScan(basePackages = "cn.sino.mark.dao.mapper")
@SuppressWarnings("java:S1874")
public class MybatisPlusConfig implements MetaObjectHandler {

    /**
     * 新的分页插件
     * -----------
     * 一缓和二缓遵循mybatis的规则,需要设置 MybatisConfiguration#useDeprecatedExecutor = false
     * 避免缓存出现问题(该属性会在旧插件移除后一同移除)
     */
    @Bean
    public MybatisPlusInterceptor mybatisPlusInterceptor() {
        var interceptor = new MybatisPlusInterceptor();
        interceptor.addInnerInterceptor(new PaginationInnerInterceptor(DbType.MYSQL));
        return interceptor;
    }

    @Bean
    public ConfigurationCustomizer configurationCustomizer() {
        return configuration -> configuration.setUseDeprecatedExecutor(false);
    }

    @Override
    public void insertFill(MetaObject metaObject) {
        Long loginUserId = LoginUserUtil.getLoginUserId();
        if (loginUserId == null || loginUserId < 0) {
            loginUserId = Constant.DEFAULT_BY;
        }
        LocalDateTime now = LocalDateTime.now();
        this.strictInsertFill(metaObject, "isDelete", Boolean.class, Boolean.FALSE);
        this.strictInsertFill(metaObject, "createBy", Long.class, loginUserId);
        this.strictInsertFill(metaObject, "createTime", LocalDateTime.class, now);
        this.strictInsertFill(metaObject, "updateBy", Long.class, loginUserId);
        this.strictInsertFill(metaObject, "updateTime", LocalDateTime.class, now);
    }

    @Override
    public void updateFill(MetaObject metaObject) {
        Long loginUserId = LoginUserUtil.getLoginUserId();
        if (loginUserId == null || loginUserId < 0) {
            loginUserId = Constant.DEFAULT_BY;
        }
        this.strictUpdateFill(metaObject, "updateBy", Long.class, loginUserId);
        this.strictUpdateFill(metaObject, "updateTime", LocalDateTime.class, LocalDateTime.now());
    }

    @Bean
    public TransactionManager transactionManager(DataSource dataSource) {
        DataSourceTransactionManager transactionManager = new DataSourceTransactionManager();
        transactionManager.setDataSource(dataSource);
        return transactionManager;
    }
}