package cn.sino.mark.common.config.security.permission;

import cn.hutool.json.JSONUtil;
import cn.sino.mark.common.constants.Constant;
import cn.sino.mark.common.model.dto.LoginUserDTO;
import org.springframework.context.annotation.Configuration;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.security.access.PermissionEvaluator;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;

import java.io.Serializable;
import java.util.Arrays;
import java.util.List;

/**
 * @author zhangamin
 * @description 自定义权限表达式
 * @className cn.sino.coop.common.config.security.permission.CusPermissionEvaluator
 * @date 2022/3/16
 */
@Configuration
public class CusPermissionEvaluator implements PermissionEvaluator {

    private final StringRedisTemplate stringRedisTemplate;

    public CusPermissionEvaluator(StringRedisTemplate stringRedisTemplate) {
        this.stringRedisTemplate = stringRedisTemplate;
    }

    @Override
    public boolean hasPermission(Authentication authentication, Object targetDomainObject, Object permission) {
        return false;
    }

    @Override
    public boolean hasPermission(Authentication authentication, Serializable targetId, String targetType, Object permission) {
        return false;
    }

    public boolean hasAnyRole(String... roles) {
        LoginUserDTO loginUser = (LoginUserDTO) SecurityContextHolder.getContext().getAuthentication().getPrincipal();
        String loginKey = Constant.ADMIN_LOGIN_KEY + loginUser.getUuid();
        //从缓存中取用户角色
        Object loginRoles = stringRedisTemplate.opsForHash().get(loginKey, Constant.LOGIN_USER_ROLES);
        if (loginRoles == null) {
            return false;
        }
        List<String> roleList = JSONUtil.toList(loginRoles.toString(), String.class);
        //判断角色code是否匹配
        return Arrays.stream(roles).anyMatch(roleList::contains);
    }

    public boolean hasPermission(String permission) {
        LoginUserDTO loginUser = (LoginUserDTO) SecurityContextHolder.getContext().getAuthentication().getPrincipal();
        String loginKey = Constant.ADMIN_LOGIN_KEY + loginUser.getUuid();
        //从缓存中取用户角色
        Object loginRoles = stringRedisTemplate.opsForHash().get(loginKey, Constant.LOGIN_USER_ROLES);
        if (loginRoles == null) {
            return false;
        }
        List<String> roles = JSONUtil.toList(loginRoles.toString(), String.class);
        if (roles.contains(Constant.ADMIN_ROLE)) {
            return true;
        }
        Object loginPerms = stringRedisTemplate.opsForHash().get(loginKey, Constant.LOGIN_USER_PERMS);
        if (loginPerms == null) {
            return false;
        }
        List<String> perms = JSONUtil.toList(loginPerms.toString(), String.class);
        return perms.contains(permission);
    }

    public boolean hasAnyPermission(String... permission) {
        LoginUserDTO loginUser = (LoginUserDTO) SecurityContextHolder.getContext().getAuthentication().getPrincipal();
        String loginKey = Constant.ADMIN_LOGIN_KEY + loginUser.getUuid();
        //从缓存中取用户角色
        Object loginRoles = stringRedisTemplate.opsForHash().get(loginKey, Constant.LOGIN_USER_ROLES);
        if (loginRoles == null) {
            return false;
        }
        List<String> roles = JSONUtil.toList(loginRoles.toString(), String.class);
        if (roles.contains(Constant.ADMIN_ROLE)) {
            return true;
        }

        Object loginPerms = stringRedisTemplate.opsForHash().get(loginKey, Constant.LOGIN_USER_PERMS);
        if (loginPerms == null) {
            return false;
        }
        List<String> perms = JSONUtil.toList(loginPerms.toString(), String.class);

        //匹配关系：anyMatch
        return Arrays.stream(permission).anyMatch(perms::contains);
    }
}
