package cn.sino.mark.common.filter;

import cn.hutool.json.JSONUtil;
import cn.sino.common.exception.BizException;
import cn.sino.common.vo.RestResponseVO;
import cn.sino.mark.common.config.security.SysUserDetails;
import cn.sino.mark.common.constants.Constant;
import cn.sino.mark.common.model.dto.LoginUserDTO;
import cn.sino.mark.common.model.dto.UserLoginDTO;
import cn.sino.mark.service.SysUserService;
import cn.sino.mark.service.convert.SysUserMapStruct;
import com.fasterxml.jackson.databind.ObjectMapper;
import org.springframework.http.MediaType;
import org.springframework.security.authentication.AuthenticationManager;
import org.springframework.security.authentication.UsernamePasswordAuthenticationToken;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.AuthenticationException;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.security.web.authentication.AbstractAuthenticationProcessingFilter;
import org.springframework.security.web.util.matcher.AntPathRequestMatcher;

import javax.servlet.FilterChain;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.util.ArrayList;


/**
 * @author zhangamin
 * @description 处理用户登录的过滤器
 * @className cn.sino.coop.common.filter.LoginFilter
 * @date 2021/12/22
 */
public class LoginFilter extends AbstractAuthenticationProcessingFilter {

    private SysUserService sysUserService;
    private ObjectMapper objectMapper;

    public LoginFilter(String url, AuthenticationManager authManager) {
        super(new AntPathRequestMatcher(url));
        setAuthenticationManager(authManager);
    }

    public LoginFilter(String url, AuthenticationManager authManager, SysUserService sysUserService, ObjectMapper objectMapper) {
        this(url, authManager);
        this.objectMapper = objectMapper;
        this.sysUserService = sysUserService;
    }

    @Override
    public Authentication attemptAuthentication(HttpServletRequest request, HttpServletResponse response) throws IOException {
        UserLoginDTO userLoginInfo = objectMapper.readValue(request.getInputStream(), UserLoginDTO.class);
        // 返回一个验证令牌
        UsernamePasswordAuthenticationToken usernamePasswordAuthenticationToken = new UsernamePasswordAuthenticationToken(
                userLoginInfo.getAccount(), userLoginInfo.getPassword());
        return getAuthenticationManager().authenticate(usernamePasswordAuthenticationToken);
    }

    @Override
    protected void successfulAuthentication(HttpServletRequest request, HttpServletResponse response, FilterChain chain, Authentication authResult) throws IOException {
        //登录成功处理
        SysUserDetails principal = (SysUserDetails) authResult.getPrincipal();
        LoginUserDTO loginUser = SysUserMapStruct.INSTANCE.convertToLoginUserDTO(principal);
        UsernamePasswordAuthenticationToken authentication = new UsernamePasswordAuthenticationToken(loginUser, null, new ArrayList<>());
        SecurityContextHolder.getContext().setAuthentication(authentication);
        String token = sysUserService.createUserLoginToken(principal.getUsername());
        response.setContentType(MediaType.APPLICATION_JSON_VALUE);
        response.setStatus(HttpServletResponse.SC_OK);
        RestResponseVO<Object> success = RestResponseVO.success(token);
        response.getWriter().println(JSONUtil.toJsonStr(success));
    }

    @Override
    protected void unsuccessfulAuthentication(HttpServletRequest request, HttpServletResponse response, AuthenticationException failed) throws IOException {
        response.setContentType(Constant.APPLICATION_JSON_UTF8_VALUE);
        response.setStatus(HttpServletResponse.SC_OK);
        RestResponseVO<Object> fail = RestResponseVO.fail(new BizException(failed.getMessage()));
        response.getWriter().println(JSONUtil.toJsonStr(fail));
    }

}
