package cn.sino.mark.common.model.dto;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import java.time.LocalDateTime;

/**
 * @author zhangamin
 * @description 新增项目
 * @className cn.sino.mark.common.model.dto.AddProjectDTO
 * @date 2022/3/27
 */
@Data
@ApiModel
public class AddProjectDTO {

    /**
     * 项目名称
     */
    @ApiModelProperty(value = "项目名称", required = true)
    @NotBlank(message = "项目名称不能为空")
    @Size(min = 1, max = 45, message = "项目名称长度在{min}~{max}之间")
    private String projectName;

    /**
     * 项目分组
     */
    @ApiModelProperty(value = "项目分组", required = true)
    @NotNull(message = "项目分组不能为空")
    private Long groupId;

    /**
     * 有效期开始时间
     */
    @ApiModelProperty(value = "有效期开始时间", required = true)
    @NotNull(message = "有效期开始时间不能为空")
    private LocalDateTime beginTime;

    /**
     * 有效期结束时间
     */
    @ApiModelProperty(value = "有效期结束时间", required = true)
    @NotNull(message = "有效期结束时间不能为空")
    private LocalDateTime endTime;

    /**
     * 推送时间
     */
    @ApiModelProperty(value = "推送时间", required = true)
    @NotNull(message = "推送时间不能为空")
    private LocalDateTime pushTime;

    /**
     * 项目描述
     */
    @ApiModelProperty(value = "项目描述")
    private String description;

    /**
     * 是否编辑(0:新增,1:编辑)
     */
    @ApiModelProperty("是否编辑(0:新增,1:编辑)")
    @NotNull(message = "是否编辑不能为空")
    private Integer isEdit;

    /**
     * 项目id(编辑才有)
     */
    @ApiModelProperty("项目id(编辑才有)")
    private Long projectId;

}