package cn.sino.mark.common.model.dto;

import io.swagger.annotations.*;
import io.swagger.annotations.ApiModel;
import lombok.Data;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Pattern;
import javax.validation.constraints.Size;

/**
 * @author sch
 * @description 新增用户
 * @className cn.sino.mark.common.model.dto.AddUserDTO
 * @date 2022/3/29
 */
@Data
@ApiModel
public class AddUserDTO {
    /**
     * 登录账号
     */
    @ApiModelProperty("登录账号")
    @NotBlank(message = "登录账号不能为空")
    @Size(min = 5, max = 16, message = "登录账号长度在{min}~{max}之间")
    @Pattern(regexp = "^[A-Za-z0-9]+$", message = "登录帐号只能是字母或数字")
    private String account;

    /**
     * 姓名
     */
    @ApiModelProperty("姓名")
    @NotBlank(message = "用户姓名不能为空")
    @Size(min = 1, max = 20, message = "用户姓名长度在{min}~{max}之间")
    private String userName;

    /**
     * 密码
     */
    @ApiModelProperty("密码")
    @NotBlank(message = "密码不能为空")
    @Size(min = 9, max = 16, message = "密码长度在{min}~{max}之间")
    @Pattern(regexp = "^[A-Za-z0-9]+$", message = "大于8位，包含字母和数字")
    private String password;

    /**
     * 确认密码
     */
    @ApiModelProperty("确认密码")
    @Size(min = 9, max = 16, message = "确认密码长度在{min}~{max}之间")
    @NotNull(message = "确认密码不能为空")
    @Pattern(regexp = "^[A-Za-z0-9]+$", message = "大于8位，包含字母和数字")
    private String confirmedPassword;

    /**
     * 是否作废（0：正常，1：作废）
     */
    @ApiModelProperty("是否作废（0：正常，1：作废）")
    @NotNull(message = "请选择是否作废")
    private Integer status;
}
