package cn.sino.mark.common.model.dto;


import org.springframework.web.multipart.MultipartFile;

import javax.validation.constraints.NotEmpty;
import java.io.*;

/**
 * @author sch
 * @description 上传文件
 * @className cn.sino.mark.common.model.dto.MultipartFileDTO
 * @date 2022/4/11
 */
public class MultipartFileDTO implements MultipartFile, Serializable {

    /**
     * 文件名
     */
    @NotEmpty(message = "文件名称不能为空")
    private String originalFilename;

    /**
     * 文件类型
     */
    @NotEmpty(message = "文件类型不能为空")
    private String contentType;

    /**
     * 文件内容
     */
    private byte[] bytes;

    @Override
    public String getName() {
        return "file";
    }

    @Override
    public String getOriginalFilename() {
        return originalFilename;
    }

    public void setOriginalFilename(String originalFilename) {
        this.originalFilename = originalFilename;
    }

    @Override
    public String getContentType() {
        return contentType;
    }

    @Override
    public boolean isEmpty() {
        return bytes == null || bytes.length == 0;
    }

    @Override
    public long getSize() {
        return bytes.length;
    }

    public void setContentType(String contentType) {
        this.contentType = contentType;
    }

    @Override
    public byte[] getBytes() {
        return bytes;
    }

    @Override
    public InputStream getInputStream() {
        return new ByteArrayInputStream(bytes);
    }

    @Override
    public void transferTo(File dest) throws IOException, IllegalStateException {
        try (FileOutputStream fileOutputStream = new FileOutputStream(dest)) {
            fileOutputStream.write(bytes);
        }
    }

    public void setBytes(byte[] bytes) {
        this.bytes = bytes;
    }
}
