package cn.sino.mark.common.utils;

import java.beans.PropertyDescriptor;
import java.lang.reflect.Field;
import java.lang.reflect.Method;

/**
 * 比较对象值变化,用于日志记录
 *
 * @Author: Live.InPast
 * @Date: 2020/11/28
 */
public class CompareHelper<T> {

    /**
     * 对象比较器
     * 比较结果eg：1、字段名称loginName,旧值:liu,新值:gu;2、字段名称address,旧值:hunan,新值:neimenggu
     * @param oldBean
     * @param newBean
     * @return
     */
    public String compareObject(Object oldBean, Object newBean) {
        String str = "";

        T pojo1 = (T) oldBean;
        T pojo2 = (T) newBean;
        try {
            Class clazz = pojo1.getClass();
            Field[] fields = pojo1.getClass().getDeclaredFields();
            for (Field field : fields) {
                if ("serialVersionUID".equals(field.getName())) {
                    continue;
                }
                PropertyDescriptor pd = new PropertyDescriptor(field.getName(), clazz);
                Method getMethod = pd.getReadMethod();
                Object o1 = getMethod.invoke(pojo1);
                Object o2 = getMethod.invoke(pojo2);
                if (o1 == null || o2 == null) {
                    continue;
                }
                if (!o1.toString().equals(o2.toString())) {
                    str += field.getName() + ": " + (o1.equals("")?"空":o1) + " => " + (o2.equals("")?"空":o2) + "\n";
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return str;
    }

}
