package cn.sino.mark.common.utils;

import cn.hutool.json.JSONUtil;
import cn.sino.common.exception.BizException;
import cn.sino.common.vo.RestResponseVO;
import cn.sino.mark.common.model.vo.InnerLoginUserVO;
import cn.sino.mark.common.model.vo.InnerUserVO;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.MediaType;
import org.springframework.http.converter.StringHttpMessageConverter;
import org.springframework.web.client.RestTemplate;

import java.nio.charset.StandardCharsets;
import java.util.List;

import static cn.hutool.core.collection.CollUtil.isEmpty;

/**
 * @author sch
 * @description http工具类
 * @className cn.sino.mark.common.utils.HttpUtil
 * @date 2022/4/20
 */
public class HttpUtil {

    public static InnerUserVO getInnerUserInfo(String url, String requestBody) {
        RestTemplate client = getRestTemplate();
        client.getMessageConverters().add(0, new StringHttpMessageConverter(StandardCharsets.UTF_8));
        HttpHeaders headers = getHttpHeaders();

        // 以json的方式提交
        headers.setContentType(MediaType.APPLICATION_JSON);

        // 将请求头部和参数合成一个请求
        HttpEntity<String> requestEntity = new HttpEntity<>(requestBody, headers);
        // 执行HTTP请求
        RestResponseVO<Object> responseVO = client.postForEntity(url, requestEntity, RestResponseVO.class).getBody();
        if (responseVO == null) {
            throw new BizException("调用内部用户信息接口失败");
        }
        List<Object> list = (List<Object>) responseVO.getResult();
        if (isEmpty(list)) {
            throw new BizException("暂未查询到内部用户信息");
        }
        return JSONUtil.toBean(JSONUtil.toJsonStr(list.get(0)), InnerUserVO.class);
    }
    public static InnerLoginUserVO getInnerLoginUserInfo(String url, String requestBody) {
        RestTemplate client = getRestTemplate();
        client.getMessageConverters().add(0, new StringHttpMessageConverter(StandardCharsets.UTF_8));
        HttpHeaders headers = getHttpHeaders();

        // 以json的方式提交
        headers.setContentType(MediaType.APPLICATION_JSON);

        // 将请求头部和参数合成一个请求
        HttpEntity<String> requestEntity = new HttpEntity<>(requestBody, headers);
        // 执行HTTP请求
        RestResponseVO<Object> responseVO = client.postForEntity(url, requestEntity, RestResponseVO.class).getBody();
        if (responseVO == null) {
            throw new BizException("调用内部用户登录接口失败");
        }
        return JSONUtil.toBean(JSONUtil.toJsonStr(responseVO.getResult()), InnerLoginUserVO.class);
    }

    public static RestTemplate getRestTemplate() {
        return new RestTemplate();
    }

    public static HttpHeaders getHttpHeaders() {
        return new HttpHeaders();
    }
}
