package cn.sino.mark.common.utils;


import cn.sino.mark.common.constants.Constant;
import cn.sino.mark.common.model.dto.LoginUserDTO;
import lombok.AccessLevel;
import lombok.NoArgsConstructor;
import org.springframework.security.authentication.AnonymousAuthenticationToken;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;


/**
 * @author zhangamin
 * @className cn.sino.coop.common.utils.LoginUserUtil
 * @description 从Spring Security的Context获取登录的用户信息
 * @date 2021/12/22
 */
@NoArgsConstructor(access = AccessLevel.PRIVATE)
public class LoginUserUtil {

    /**
     * 获取当前登陆用户信息
     *
     * @return cn.sino.coop.common.model.dto.LoginUserDTO
     */
    public static LoginUserDTO getLoginUser() {
        Authentication authentication = SecurityContextHolder.getContext().getAuthentication();
        if (authentication == null) {
            return null;
        }
        if (authentication instanceof AnonymousAuthenticationToken) {
            return null;
        }
        return (LoginUserDTO) authentication.getPrincipal();
    }

    /**
     * 获取当前登陆用户id
     *
     * @return 后台登录用户ID
     */
    public static Long getLoginUserId() {
        LoginUserDTO loginUser = getLoginUser();
        return loginUser == null ? Constant.DEFAULT_BY : loginUser.getUserId();
    }

}
