package cn.sino.mark.controller.web;

import cn.sino.common.base.PageResult;
import cn.sino.common.vo.RestResponseVO;
import cn.sino.mark.common.model.dto.AddLabelDTO;
import cn.sino.mark.common.model.dto.EditLabelDTO;
import cn.sino.mark.common.model.dto.LabelPageDTO;
import cn.sino.mark.common.model.vo.LabelAllVO;
import cn.sino.mark.common.model.vo.LabelInfoVO;
import cn.sino.mark.common.model.vo.LabelPageVO;
import cn.sino.mark.service.LabelService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

/**
 * @Description 标签接口
 * @Author sch
 * @Date 2022/9/8 14:03
 **/
@Api(tags = "标签接口")
@RestController
@RequestMapping("/label")
@RequiredArgsConstructor
public class LabelController {
    
    private final LabelService labelService;

    @ApiOperation("添加标签")
    @PostMapping("/add")
    @PreAuthorize("hasPermission('add-label')")
    public RestResponseVO<Void> add(@Valid @RequestBody AddLabelDTO reqDTO) {
        labelService.addLabel(reqDTO);
        return RestResponseVO.success();
    }

    @ApiOperation("编辑标签")
    @PutMapping("/edit")
    @PreAuthorize("hasPermission('edit-label')")
    public RestResponseVO<Void> edit(@Valid @RequestBody EditLabelDTO reqDTO) {
        labelService.editLabel(reqDTO);
        return RestResponseVO.success();
    }

    @ApiOperation("删除标签")
    @ApiImplicitParam(name = "id", value = "标签id", paramType = "path", dataTypeClass = Long.class, required = true)
    @DeleteMapping("/delete/{id}")
    @PreAuthorize("hasPermission('delete-label')")
    public RestResponseVO<Void> delete(@PathVariable("id") Long id) {
        labelService.delete(id);
        return RestResponseVO.success();
    }

    @ApiOperation("分页查询标签")
    @PostMapping("/page")
    public RestResponseVO<PageResult<LabelPageVO>> getPage(@RequestBody LabelPageDTO reqDTO) {
        return RestResponseVO.success(labelService.getPage(reqDTO));
    }

    @ApiOperation("查询标签详情")
    @ApiImplicitParam(name = "id", value = "标签id", paramType = "path", dataTypeClass = Long.class, required = true)
    @GetMapping("/info/{id}")
    public RestResponseVO<LabelInfoVO> selectInfo(@PathVariable("id") Long id) {
        return RestResponseVO.success(labelService.selectInfo(id));
    }

    @ApiOperation("查询所有标签")
    @GetMapping("/get-all")
    public RestResponseVO<List<LabelAllVO>> selectInfo() {
        return RestResponseVO.success(labelService.selectAll());
    }
}
