package cn.sino.mark.controller.web;

import cn.sino.common.exception.BizException;
import cn.sino.common.vo.RestResponseVO;
import cn.sino.mark.common.model.dto.AddProjectGroupDTO;
import cn.sino.mark.common.model.dto.ModifyProjectGroupDTO;
import cn.sino.mark.common.model.vo.ProjectGroupTreeVO;
import cn.sino.mark.service.ProjectGroupService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

/**
 * @author zhangamin
 * @description 项目分组管理控制层
 * @className cn.sino.mark.controller.web.CategoryController
 * @date 2022/3/27
 */
@Api(tags = "项目分组管理")
@RestController
@RequestMapping("/project/group")
@RequiredArgsConstructor
public class ProjectGroupController {
    private final ProjectGroupService groupService;

    @ApiOperation("获取分组树列表")
    @GetMapping("/tree")
    public RestResponseVO<List<ProjectGroupTreeVO>> tree() {
        return RestResponseVO.success(groupService.getTree());
    }

    @ApiOperation("新增分组")
    @PostMapping("/add")
    @PreAuthorize("hasPermission('add-group-btn')")
    public RestResponseVO<Void> add(@Valid @RequestBody AddProjectGroupDTO addProjectGroupDTO) {
        groupService.addGroup(addProjectGroupDTO);
        return RestResponseVO.success();
    }

    @ApiOperation("修改分组")
    @PutMapping("/edit/{groupId}")
    @PreAuthorize("hasPermission('modify-group-btn')")
    @ApiImplicitParam(name = "groupId", value = "分组ID", paramType = "path", dataTypeClass = Long.class, required = true)
    public RestResponseVO<Void> modify(@Valid @RequestBody ModifyProjectGroupDTO modifyProjectGroupDTO, @PathVariable("groupId") Long groupId) {
        if (groupId == null) {
            throw new BizException("请求参数错误");
        }
        groupService.modifyGroup(modifyProjectGroupDTO, groupId);
        return RestResponseVO.success();
    }

    @ApiOperation("删除(作废)分组")
    @ApiImplicitParam(name = "groupId", value = "分组ID", paramType = "path", dataTypeClass = Long.class, required = true)
    @DeleteMapping("/{groupId}")
    @PreAuthorize("hasPermission('delete-group-btn')")
    public RestResponseVO<Void> remove(@PathVariable("groupId") Long groupId) {
        if (groupId == null) {
            throw new BizException("请求参数错误");
        }
        groupService.removeGroup(groupId);
        return RestResponseVO.success();
    }

}