package cn.sino.mark.controller.web;


import cn.sino.common.vo.RestResponseVO;
import cn.sino.mark.common.model.dto.AddPermReqDTO;
import cn.sino.mark.common.model.dto.DeletePermReqDTO;
import cn.sino.mark.common.model.dto.EditPermReqDTO;
import cn.sino.mark.common.model.vo.PermResDTO;
import cn.sino.mark.common.model.vo.SysPermInfoResDTO;
import cn.sino.mark.service.SysPermService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

/**
 * 权限接口
 *
 * @author zhangamin
 * @date 2020/11/23
 */
@RestController
@RequestMapping("/sys-perm")
@Api(tags = "权限接口")
public class SysPermController {

    private final SysPermService sysPermService;

    public SysPermController(SysPermService sysPermService) {
        this.sysPermService = sysPermService;
    }


    @ApiOperation("查询所有菜单")
    @GetMapping("/menu-tree")
    public RestResponseVO<List<PermResDTO>> getAllMenu() {
        return RestResponseVO.success(sysPermService.getAllMenuList());
    }


    @ApiOperation("查询菜单下的权限列表")
    @GetMapping("/menu-perm/{menuId}")
    public RestResponseVO<List<PermResDTO>> getMenuPerms(@PathVariable Long menuId) {
        return RestResponseVO.success(sysPermService.getPermsByMenuId(menuId));
    }


    @ApiOperation("添加菜单/权限")
    @PostMapping("/add")
    @PreAuthorize("hasRole('Administrator')")
    public RestResponseVO<Void> add(@Valid @RequestBody AddPermReqDTO addPermReqDTO) {
        sysPermService.addPerm(addPermReqDTO);
        return RestResponseVO.success();
    }

    @ApiOperation("查询权限明细")
    @GetMapping("/info/{permId}")
    public RestResponseVO<SysPermInfoResDTO> getPermInfo(@PathVariable Long permId) {
        return RestResponseVO.success(sysPermService.getSysPermInfo(permId));
    }

    @ApiOperation("修改权限")
    @PutMapping("/edit")
    @PreAuthorize("hasRole('Administrator')")
    public RestResponseVO<Void> edit(@Valid @RequestBody EditPermReqDTO editPermReqDTO) {
        sysPermService.editPerm(editPermReqDTO);
        return RestResponseVO.success();
    }

    @ApiOperation("删除权限")
    @DeleteMapping("/{permId}")
    @PreAuthorize("hasRole('Administrator')")
    public RestResponseVO<Void> delete(@PathVariable Long permId) {
        sysPermService.deleteById(permId);
        return RestResponseVO.success();
    }

    @ApiOperation("上移/下移 权限信息")
    @PutMapping("/move/{type}/{permId}")
    @PreAuthorize("hasRole('Administrator')")
    public RestResponseVO<Void> sort(@PathVariable("type") Integer type, @PathVariable("permId") Long permId) {
        sysPermService.movePermNode(permId, type);
        return RestResponseVO.success();
    }

    @ApiOperation("批量删除权限")
    @PutMapping("/delete-more")
    @PreAuthorize("hasRole('Administrator')")
    public RestResponseVO<Void> deleteMore(@Valid @RequestBody DeletePermReqDTO permIds) {
        sysPermService.deleteMoreByIds(permIds);
        return RestResponseVO.success();
    }

    @ApiOperation("查询非默认的权限")
    @GetMapping("/all/not-default")
    public RestResponseVO<List<PermResDTO>> notDefault() {
        List<PermResDTO> permResDTOList = sysPermService.getNotDefaultPerm();
        return RestResponseVO.success(permResDTOList);
    }
}
