package cn.sino.mark.controller.web;


import cn.sino.common.vo.RestResponseVO;
import cn.sino.mark.common.model.dto.AddRoleReqDTO;
import cn.sino.mark.common.model.dto.AssignPermsReqDTO;
import cn.sino.mark.common.model.dto.EditRoleReqDTO;
import cn.sino.mark.common.model.dto.SysRolePageQueryReqDTO;
import cn.sino.mark.common.model.vo.PermResDTO;
import cn.sino.mark.common.model.vo.RoleResDTO;
import cn.sino.mark.common.model.vo.SysRoleInfoVO;
import cn.sino.mark.service.SysRoleService;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

/**
 * @author sch
 * @description 角色接口
 * @className cn.sino.mark.controller.web.SysRoleController
 * @date 2022/4/18
 */
@RestController
@RequestMapping("/role")
@Api( tags = "角色接口")
public class SysRoleController {

    private final SysRoleService sysRoleService;

    public SysRoleController(SysRoleService sysRoleService) {
        this.sysRoleService = sysRoleService;
    }


    @ApiOperation("分页查询所有角色")
    @PostMapping("/page")
    public RestResponseVO<PageInfo<RoleResDTO>> getPage(@RequestBody SysRolePageQueryReqDTO sysRolePageQuery) {
        return RestResponseVO.success(sysRoleService.getRolePage(sysRolePageQuery));
    }

    @ApiOperation("添加角色")
    @PostMapping("/add")
    public RestResponseVO<Void> add(@Valid @RequestBody AddRoleReqDTO addRoleReqDTO) {
        sysRoleService.addRole(addRoleReqDTO);
        return RestResponseVO.success();
    }

    @ApiOperation("编辑角色")
    @PutMapping("/edit")
    public RestResponseVO<Void> edit(@Valid @RequestBody EditRoleReqDTO editRoleReqDTO) {
        sysRoleService.editRole(editRoleReqDTO);
        return RestResponseVO.success();
    }

    @ApiOperation("删除角色")
    @DeleteMapping("/{roleId}")
    public RestResponseVO<Void> delete(@PathVariable Long roleId) {
        sysRoleService.deleteById(roleId);
        return RestResponseVO.success();
    }

    @ApiOperation("查询角色拥有的权限")
    @GetMapping("/perms/{roleId}")
    public RestResponseVO<List<PermResDTO>> getPermsByRoleId(@PathVariable Long roleId) {
        List<PermResDTO> permListResDTO = sysRoleService.getPermsByRoleId(roleId);
        return RestResponseVO.success(permListResDTO);
    }

    @ApiOperation("给角色分配权限")
    @PostMapping("/assign-perms")
    public RestResponseVO<Void> assignPerms(@Valid @RequestBody AssignPermsReqDTO assignPermsReqDTO) {
        sysRoleService.addRolePerms(assignPermsReqDTO);
        return RestResponseVO.success();
    }

    @ApiOperation("根据角色id查询")
    @GetMapping("/{roleId}")
    public RestResponseVO<RoleResDTO> getRoleById(@PathVariable Long roleId) {
        RoleResDTO roleResDTO = sysRoleService.getRoleById(roleId);
        return RestResponseVO.success(roleResDTO);
    }

    @ApiOperation("查询所有角色")
    @GetMapping("/all")
    public RestResponseVO<List<SysRoleInfoVO>> all() {
        List<SysRoleInfoVO> roleListResDTO = sysRoleService.getAllRole();
        return RestResponseVO.success(roleListResDTO);
    }

}
