package cn.sino.mark.dao.mapper;

import cn.sino.mark.common.model.bo.ExportDataBO;
import cn.sino.mark.common.model.bo.ProjectTaskDetailBO;
import cn.sino.mark.common.model.dto.ExportTaskDTO;
import cn.sino.mark.dao.model.ProjectTaskDetailDO;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * @author shichanghao
 * @description 针对表【t_project_task_detail(项目任务明细表)】的数据库操作Mapper
 * @date 2022-04-04 19:42:16
 * @className cn.sino.mark.dao.model.ProjectTaskDetailDO
 */
public interface ProjectTaskDetailMapper extends BaseMapper<ProjectTaskDetailDO> {

    /**
     * 批量新增任务明细
     *
     * @param list 集合
     */
    void insertBatch(@Param("list") List<ProjectTaskDetailDO> list);

    /**
     * 查询任务明细
     *
     * @param taskId 任务id
     * @return List<ProjectTaskDetailBO>
     */
    List<ProjectTaskDetailBO> selectDetailBOsByTaskId(@Param("taskId") Long taskId);

    /**
     * 导出标注结果
     *
     * @param exportTaskDTO 导出条件
     * @return List<ExportDataBO>
     */
    List<ExportDataBO> exportTaskDetails(ExportTaskDTO exportTaskDTO);

    /**
     * 分页查询任务明细
     *
     * @param taskId 任务id
     * @param dataId 资源数据id
     * @param type   类型
     * @return List<ProjectTaskDetailBO>
     */
    List<ProjectTaskDetailBO> selectDetailBOPageByTaskId(@Param("taskId") Long taskId, @Param("dataId") Long dataId, @Param("type") Long type);

    /**
     * 查看任务是否全部标注完成
     *
     * @param taskId 任务id
     * @return int
     */
    int checkTaskFinish(@Param("taskId") Long taskId);

    /**
     * 查询任务标注数量
     *
     * @param taskId     任务id
     * @param type       标注类型
     * @param hasProblem 是否存疑
     * @return int
     */
    int selectMarkNumByTask(@Param("taskId") Long taskId, @Param("type") Integer type, @Param("hasProblem") Integer hasProblem);

    /**
     * 查询任务验证数量
     *
     * @param taskId     任务id
     * @param sampleType 验证结果
     * @return int
     */
    int selectSampleNumByTask(@Param("taskId") Long taskId, @Param("sampleType") Integer sampleType);

    /**
     * 查询任务明细id集合
     *
     * @param taskId     任务id
     * @param sampleType 验证类型
     * @return List<Long>
     */
    List<Long> selectDetailIdsByTask(@Param("taskId") Long taskId, @Param("sampleType") Integer sampleType);

    /**
     * 根据id集合查询
     *
     * @param detailIds id集合
     * @return List<ProjectTaskDetailBO>
     */
    List<ProjectTaskDetailBO> selectDetailBOsByIds(List<Long> detailIds);
}




