package cn.sino.mark.dao.mapper;

import cn.sino.mark.common.model.bo.ProjectTaskBO;
import cn.sino.mark.common.model.dto.QueryTaskDTO;
import cn.sino.mark.dao.model.ProjectTaskDO;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.github.pagehelper.Page;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * @author shichanghao
 * @description 针对表【t_project_task】的数据库操作Mapper
 * @date 2022-04-04 19:42:05
 * @className cn.sino.mark.dao.model.ProjectTaskDO
 */
public interface ProjectTaskMapper extends BaseMapper<ProjectTaskDO> {

    /**
     * 批量新增项目-任务
     *
     * @param list 集合
     */
    void insertBatch(@Param("list") List<ProjectTaskDO> list);

    /**
     * 根据项目id分页查询任务
     *
     * @param projectId 项目id
     * @return Page<ProjectTaskBO>
     */
    Page<ProjectTaskBO> selectPageByProjectId(@Param("projectId") Long projectId);

    /**
     * 查询项目任务数量
     *
     * @param projectId 项目id
     * @return int
     */
    Integer selectTotalByProjectId(@Param("projectId") Long projectId);

    /**
     * 查询用户的任务数量
     *
     * @param userId     用户id
     * @param isComplete 是否完成
     * @return int
     */
    Integer selectTaskNumByUserId(@Param("userId") Long userId, @Param("isComplete") Integer isComplete);

    /**
     * 分页查询任务
     *
     * @param queryTaskDTO 查询条件
     * @return Page<ProjectTaskBO>
     */
    Page<ProjectTaskBO> selectTaskPage(QueryTaskDTO queryTaskDTO);

    /**
     * 任务总数
     *
     * @param queryTaskDTO 查询条件
     * @return int
     */
    Integer selectTaskPageTotal(QueryTaskDTO queryTaskDTO);

    /**
     * 查询未完成的任务
     *
     * @param userId 用户id
     * @return List<ProjectTaskBO>
     */
    List<ProjectTaskBO> selectNotCompTasksByUserId(@Param("userId") Long userId);
}




