package cn.sino.mark.dao.mapper;

import cn.sino.mark.common.model.bo.SysPermBO;
import cn.sino.mark.dao.model.SysPermDO;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
* @author shichanghao
* @description 针对表【t_sys_perm(系统权限表)】的数据库操作Mapper
* @createDate 2022-03-29 23:56:35
* @Entity cn.sino.mark.dao.model.SysPermDO
*/
public interface SysPermMapper extends BaseMapper<SysPermDO> {

    /**
     * 查询用户权限
     *
     * @param userId 用户ID
     * @return List<SysPermDO>
     */
    List<SysPermDO> listPermsByUserId(@Param("userId") Long userId);

    /**
     * 根据权限名称查询
     *
     * @param permName 权限名称
     * @return
     */
    SysPermDO selectByPermCode(String permName);

    /**
     * 添加权限
     *
     * @param sysPerm
     */
    int insert(SysPermDO sysPerm);

    /**
     * 根据权限id进行删除
     *
     * @param permId 权限id
     */
    int deleteById(Long permId);

    /**
     * 修改权限
     *
     * @param sysPerm
     */
    int update(SysPermDO sysPerm);

    /**
     * 根据权限id查询
     *
     * @param permId 权限id
     * @return
     */
    SysPermDO selectById(Long permId);

    /**
     * 根据parentId查询权限id列表
     *
     * @param permId
     * @return
     */
    List<Long> selectPermIdsByParentId(Long permId);

    /**
     * 根据用户id查询权限
     *
     * @param userId 用户id
     * @return
     */
    List<SysPermDO> selectByUserId(Long userId);

    /**
     * 查询is_menu=1的菜单权限
     *
     * @return
     */
//    List<SysPerm> selectIsMenu();

    /**
     * 查询is_menu = 1 的菜单权限 树结构
     *
     * @return
     */
    List<SysPermBO> selectMenuTreeData();

    /**
     * 查询is_menu=0 的权限信息
     *
     * @return
     */
//    List<SysPerm> selectNotMenu();

    /**
     * 根据权限id，查询当前权限下的子权限
     *
     * @param id
     * @return
     */
    List<SysPermDO> selectChildrenPermsById(Long id);

    /**
     * 查询菜单下的权限（非菜单）
     *
     * @param menuId 菜单ID
     * @return
     */
    List<SysPermDO> selectPermsByMenuId(Long menuId);

    /**
     * 根据userid 查询is_menu=1的权限信息
     *
     * @param userId
     * @return
     */
//    List<SysPerm> selectIsMenuByUserId(Long userId);

    /**
     * 根据userid 查询is_menu=0的权限信息
     *
     * @param userId
     * @return
     */
//    List<SysPerm> selectNotMenuByUserId(Long userId);

    /**
     * 根据角色id，查询权限(不递归查询子权限)
     *
     * @param roleId
     * @return
     */
    List<SysPermDO> selectPermsByRoleId(Long roleId);

    /**
     * 查询所有权限
     *
     * @return
     */
//    List<SysPermBO> selectAllPerm();

    /**
     * 查询所有非默认的权限
     *
     * @return
     */
    List<SysPermDO> selectAllNotDefaultPerm();

    /**
     * 批量删除
     *
     * @param permIds 权限id集合
     * @return
     */
    int deleteMoreByPermIds(List<Long> permIds);

    /**
     * 根据角色id查询权限id列表
     *
     * @param roleId 角色id
     * @return
     */
//    List<Long> selectPermIdsByRoleId(Long roleId);

    /**
     * 根据parentId查询并且存在指定权限id列表中的权限数量
     *
     * @param permId  权限id
     * @param permIds 权限id列表
     * @return
     */
//    int selectCountByParentId(@Param("permId") Long permId, @Param("permIds") List<Long> permIds);

    /**
     * 根据权限编码查询用户列表
     *
     * @param code
     * @return
     */
//    List<UserResDTO> getPermUsers(String code);

    /**
     * 查询所有未删除的权限 超级管理员专用
     *
     * @return
     */
//    List<SysPerm> selectNoDelete();

    /**
     * 根据权限code查用户ID
     *
     * @param code
     * @return
     */
//    List<Long> selectUserIdsByPermCode(String code);

    /**
     * 查询所有默认拥有的权限id
     *
     * @return
     */
    List<SysPermDO> selectDefaultPerm();

//    Long selectParentDefaultPerm(Long permId);

    /**
     * 查询三级目录权限
     *
     * @return
     */
//    List<SysPerm> selectThirdPerm();

    /**
     * 根据角色ID和权限名称查询
     *
     * @param roleId
     * @param permId
     * @return
     */
//    SysPerm selectByRoleIdAndPermId(@Param("roleId") Long roleId, @Param("permId") Long permId);
}




