package cn.sino.mark.dao.mapper;

import cn.sino.mark.common.model.dto.SysRolePageQueryReqDTO;
import cn.sino.mark.dao.model.SysRoleDO;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;

import java.util.List;

/**
 * @author shichanghao
 * @description 针对表【t_sys_role(系统角色表)】的数据库操作Mapper
 * @date 2022-03-28 22:55:10
 * @className cn.sino.mark.dao.model.SysRole
 */
public interface SysRoleMapper extends BaseMapper<SysRoleDO> {

    /**
     * 查询用户角色
     *
     * @param userId 用户ID
     * @return List<SysRoleDO>
     */
    List<SysRoleDO> listRolesByUserId(Long userId);

    /**
     * 分页查询角色列表
     *
     * @return 分页信息
     */
    List<SysRoleDO> selectPage(SysRolePageQueryReqDTO reqDTO);

    /**
     * 添加角色
     *
     * @param sysRole 角色信息
     */
    int insert(SysRoleDO sysRole);

    /**
     * 根据角色id进行删除
     *
     * @param roleId 角色id
     */
    int deleteById(Long roleId);

    /**
     * 修改角色
     *
     * @param sysRole 角色信息
     */
    int updateById(SysRoleDO sysRole);

    /**
     * 根据角色名称查询角色
     *
     * @param roleName 角色名称
     * @return 角色信息
     */
    SysRoleDO selectByRoleName(String roleName);

    /**
     * 查询所有角色
     *
     * @return 角色信息
     */
    List<SysRoleDO> selectAllRole();

    /**
     * 根据角色id查询
     *
     * @param roleId 角色id
     * @return 角色信息
     */
    SysRoleDO selectById(Long roleId);

    /**
     * 根据用户id查询角色列表
     *
     * @param userId 用户id
     * @return 角色list
     */
    List<SysRoleDO> selectByUserId(Long userId);

}




