package cn.sino.mark.service;

import cn.sino.common.base.PageResult;
import cn.sino.mark.common.model.dto.*;
import cn.sino.mark.common.model.vo.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * @author shichanghao
 * @description 针对表【t_project】的数据库操作Service
 * @date 2022-04-04 19:41:27
 * @className cn.sino.mark.service.ProjectService
 */
public interface ProjectService {

    /**
     * 新增项目基本信息
     *
     * @param addProjectDTO 新增项目信息
     * @return Long
     */
    Long addProject(AddProjectDTO addProjectDTO);

    /**
     * 新增项目分类配置
     *
     * @param addProjectCategoryDTO 新增项目-分类信息
     */
    void addCategory(AddProjectCategoryDTO addProjectCategoryDTO);

    /**
     * 新增项目资源配置
     *
     * @param addProjectResourceDTO 新增项目-资源信息
     */
    void addResource(AddProjectResourceDTO addProjectResourceDTO);

    /**
     * 新增项目人员配置
     *
     * @param addProjectUserDTO 新增项目-用户信息
     */
    List<ProjectTaskAssignVO> addUsers(AddProjectUserDTO addProjectUserDTO);

    /**
     * 项目资源分配完成
     *
     * @param completeProjectDTO 参数
     * @param projectId          项目id
     */
    void assignComplete(CompleteProjectDTO completeProjectDTO, Long projectId);

    /**
     * 分页查询项目
     *
     * @param queryProjectDTO 查询条件
     * @return PageResult<ProjectPageItemVO>
     */
    PageResult<ProjectPageItemVO> getProjectPage(QueryProjectDTO queryProjectDTO);

    /**
     * 取消项目
     *
     * @param projectId 项目id
     */
    void deleteProject(Long projectId);

    /**
     * 查看项目的任务列表
     *
     * @param projectId 项目id
     * @param pageNum   页码
     * @return PageResult<ProjectTaskPageItemVO>
     */
    PageResult<ProjectTaskPageItemVO> getTaskPage(Long projectId, Integer pageNum);

    /**
     * 重新分配任务打标人
     *
     * @param reAssignProjectTaskDTO 参数
     */
    void reAssignTask(ReAssignProjectTaskDTO reAssignProjectTaskDTO);

    /**
     * 查询任务明细
     *
     * @param taskId 任务id
     * @return List<ProjectTaskDetailVO>
     */
    List<ProjectTaskDetailVO> getTaskDetails(Long taskId);

    /**
     * 打标
     *
     * @param markProjectTaskDTO 打标参数
     */
    void mark(MarkProjectTaskDTO markProjectTaskDTO);

    /**
     * 查询项目基本信息
     *
     * @param projectId 项目id
     * @return ProjectBaseInfoVO
     */
    ProjectBaseInfoVO getProjectBaseInfo(Long projectId);

    /**
     * 查询任务基本信息
     *
     * @param taskId 任务id
     * @return TaskBaseInfoVO
     */
    TaskBaseInfoVO getTaskBaseInfo(Long taskId);

    /**
     * 新增抽样验证
     *
     * @param addTaskSampleDTO 新增抽样参数
     * @return List<ProjectTaskDetailVO>
     */
    List<ProjectTaskDetailVO> addTaskSample(AddTaskSampleDTO addTaskSampleDTO);

    /**
     * 项目抽查验证
     *
     * @param markProjectTaskDTO 抽查验证参数
     */
    void sampleMark(MarkProjectTaskDTO markProjectTaskDTO);

    /**
     * 项目验证完成
     *
     * @param projectId 项目id
     */
    void verifyProject(Long projectId);

    /**
     * 分页查询我的任务
     *
     * @param queryTaskDTO 查询条件
     * @return PageResult<ProjectTaskPageItemVO>
     */
    PageResult<ProjectTaskPageItemVO> getMyTaskPage(QueryTaskDTO queryTaskDTO);

    /**
     * 查询我的任务完成情况
     *
     * @return MyTaskStatisticVO
     */
    MyTaskStatisticVO getMyTaskStatistics();

    /**
     * 标注结果查询
     *
     * @param queryTaskDTO 查询条件
     * @return PageResult<ProjectTaskPageItemVO>
     */
    PageResult<ProjectTaskPageItemVO> getMarkResultPage(QueryTaskDTO queryTaskDTO);

    /**
     * 导出标注结果
     *
     * @param exportTaskDTO 导出条件
     */
    void exportMarkResultJson(ExportTaskDTO exportTaskDTO, HttpServletResponse response);

    /**
     * 分页查询任务明细
     *
     * @param taskId 任务id
     * @param dataId 资源数据id
     * @param type   类型
     * @return List<ProjectTaskDetailVO>
     */
    List<ProjectTaskDetailVO> getTaskDetailPage(Long taskId, Long dataId, Long type);

    /**
     * 查询项目信息
     *
     * @param projectId 项目id
     * @return ProjectVO
     */
    ProjectVO getProjectById(Long projectId);

    /**
     * 查询标注结果
     *
     * @param detailId 明细id
     * @return TaskDetailVO
     */
    TaskDetailVO getTaskDetail(Long detailId);
}
