package cn.sino.mark.service;

import cn.sino.common.base.PageResult;
import cn.sino.mark.common.model.dto.AddResourceDTO;
import cn.sino.mark.common.model.dto.ImportResourceDTO;
import cn.sino.mark.common.model.dto.QueryResourceDTO;
import cn.sino.mark.common.model.vo.ImportResourceVO;
import cn.sino.mark.common.model.vo.ResourceBaseInfoVO;
import cn.sino.mark.common.model.vo.ResourcePageItemVO;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

/**
 * @author sch
 * @description 资源管理接口
 * @className cn.sino.mark.service.ResourceService
 * @date 2022/4/1
 */
public interface ResourceService {

    /**
     * 新增资源
     *
     * @param addResourceDTO 新增资源信息
     */
    Long addResource(AddResourceDTO addResourceDTO);

    /**
     * 解析资源
     *
     * @param file 文件
     * @param type 资源类型
     * @return ImportResourceVO
     */
    ImportResourceVO analyseResource(MultipartFile file, Integer type);

    /**
     * 上传资源
     *
     * @param importResourceDTO 上传参数
     */
    void importResource(ImportResourceDTO importResourceDTO);

    /**
     * 分页查询资源列表
     *
     * @param queryResourceDTO 查询条件
     * @return PageResult<ResourcePageItemDTO>
     */
    PageResult<ResourcePageItemVO> getResourcePage(QueryResourceDTO queryResourceDTO);

    /**
     * 查看资源基本信息
     *
     * @param resourceId 资源id
     * @return ResourceBaseInfoVO
     */
    ResourceBaseInfoVO getBaseInfo(Long resourceId);

    /**
     * 删除(作废)资源
     *
     * @param resourceId 资源id
     */
    void removeResource(Long resourceId);

    /**
     * 查询查看待选资源列表
     *
     * @param projectId 项目id
     * @return List<ResourceBaseInfoVO>
     */
    List<ResourceBaseInfoVO> getNotAssignedList(Long projectId);

    /**
     * 解析资源并上传
     *
     * @param uploadFile 文件
     * @param resourceId 资源id
     * @return {@link ImportResourceVO}
     */
    ImportResourceVO analyseResourceV2(MultipartFile uploadFile, Long resourceId);

    /**
     * 修改资源状态
     *
     * @param importResourceDTO 参数
     */
    void importResourceV2(ImportResourceDTO importResourceDTO);
}
