package cn.sino.mark.service;

import cn.sino.mark.common.model.dto.AddPermReqDTO;
import cn.sino.mark.common.model.dto.DeletePermReqDTO;
import cn.sino.mark.common.model.dto.EditPermReqDTO;
import cn.sino.mark.common.model.vo.PermResDTO;
import cn.sino.mark.common.model.vo.SysPermInfoResDTO;

import java.util.List;

/**
* @author shichanghao
* @description 针对表【t_sys_perm(系统权限表)】的数据库操作Service
* @createDate 2022-03-29 23:56:35
*/
public interface SysPermService{
    /**
     * 添加权限
     *
     * @param addPermReqDTO
     */
    void addPerm(AddPermReqDTO addPermReqDTO);

    /**
     * 查询权限基本信息
     *
     * @param permId 权限ID
     * @return
     */
    SysPermInfoResDTO getSysPermInfo(Long permId);

    /**
     * 根据权限id进行删除
     *
     * @param permId 权限id
     */
    void deleteById(Long permId);

    /**
     * 修改权限
     *
     * @param editPermReqDTO
     */
    void editPerm(EditPermReqDTO editPermReqDTO);

    /**
     * 根据权限id查询
     *
     * @param permId 权限id
     * @return
     */
    PermResDTO getPermById(Long permId);

    /**
     * 根据id，移动权限信息
     *
     * @param id   权限id
     * @param type 移动类型(上移/下移)
     * @return
     */
    void movePermNode(Long id, int type);

    /**
     * 查询菜单权限列表 is_menu=1 树结构
     *
     * @return
     */
    List<PermResDTO> getAllMenuList();

    /**
     * 查询菜单下的所有权限
     *
     * @param menuId 菜单id
     * @return
     */
    List<PermResDTO> getPermsByMenuId(Long menuId);

    /**
     * 批量删除权限
     *
     * @param permIds 权限id 集合
     */
    void deleteMoreByIds(DeletePermReqDTO permIds);

    /**
     * 查询非默认的权限 树结构
     * @return
     */
    List<PermResDTO> getNotDefaultPerm();
}
