package cn.sino.mark.service;

import cn.sino.mark.common.model.dto.AddRoleReqDTO;
import cn.sino.mark.common.model.dto.AssignPermsReqDTO;
import cn.sino.mark.common.model.dto.EditRoleReqDTO;
import cn.sino.mark.common.model.dto.SysRolePageQueryReqDTO;
import cn.sino.mark.common.model.vo.PermResDTO;
import cn.sino.mark.common.model.vo.RoleResDTO;
import cn.sino.mark.common.model.vo.SysRoleInfoVO;
import com.github.pagehelper.PageInfo;

import java.util.List;

/**
* @author shichanghao
* @description 针对表【t_sys_role(系统角色表)】的数据库操作Service
* @createDate 2022-03-28 22:55:10
*/
public interface SysRoleService {
    /**
     * 分页查询所有角色
     *
     * @param sysRolePageQueryReqDTO
     * @return 分页数据
     */
    PageInfo<RoleResDTO> getRolePage(SysRolePageQueryReqDTO sysRolePageQueryReqDTO);

    /**
     * 添加角色
     *
     * @param addRoleReqDTO 角色信息
     */
    void addRole(AddRoleReqDTO addRoleReqDTO);

    /**
     * 编辑角色
     *
     * @param editRoleReqDTO 角色信息
     */
    void editRole(EditRoleReqDTO editRoleReqDTO);

    /**
     * 根据角色id进行删除
     *
     * @param roleId 角色id
     */
    void deleteById(Long roleId);

    /**
     * 给角色添加权限
     *
     * @param assignPermsReqDTO 角色和权限id
     */
    void addRolePerms(AssignPermsReqDTO assignPermsReqDTO);

    /**
     * 根据角色id查询权限
     *
     * @param roleId 角色id
     * @return 查询结果
     */
    List<PermResDTO> getPermsByRoleId(Long roleId);

    /**
     * 根据角色id查询
     *
     * @param roleId 角色id
     * @return 角色信息
     */
    RoleResDTO getRoleById(Long roleId);

    /**
     * 查询所有角色
     *
     * @return  角色信息
     */
    List<SysRoleInfoVO> getAllRole();
}
