package cn.sino.mark.service;

import cn.sino.common.base.PageResult;
import cn.sino.mark.common.model.dto.*;
import cn.sino.mark.common.model.vo.*;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

/**
 * @author zhangamin
 * @description 后台管理系统用户业务接口
 * @className cn.sino.coop.service.SysUserService
 * @date 2022/3/17
 */
public interface SysUserService {

    /**
     * 生成用户可以登录的token，这个token可以登录后台管理系统
     *
     * @param account 用户登录账户
     * @return 授权Token
     */
    String createUserLoginToken(String account);

    /**
     * 新增外部用户
     *
     * @param addUserDTO 新增用户信息
     */
    void addOuterUser(AddUserDTO addUserDTO);

    /**
     * 查看外部用户信息
     *
     * @param userId 用户ID
     * @return UserDetailsVO
     */
    UserDetailsVO getOuterUserDetails(Long userId);

    /**
     * 编辑外部用户
     *
     * @param editUserDTO 编辑用户信息
     * @param userId      用户ID
     */
    void editOuterUser(EditUserDTO editUserDTO, Long userId);

    /**
     * 分页查询用户列表
     *
     * @param queryUserPageDTO 查询用户列表参数
     * @return PageInfo<UserPageVO>
     */
    PageResult<UserPageVO> getUserPage(QueryUserPageDTO queryUserPageDTO);

    /**
     * 删除外部用户
     *
     * @param userId 用户ID
     */
    void deleteUser(Long userId);

    /**
     * 查询登录用户信息
     *
     * @return LoginUserInfoVO
     */
    LoginUserInfoVO getLoginUserInfo();

    /**
     * 分配角色
     *
     * @param assignRolesDTO 分配角色参数
     */
    void assignUserRoles(AssignRolesDTO assignRolesDTO);

    /**
     * 查询待选标注人员
     *
     * @param projectId 项目id
     * @return List<UserBaseInfoVO>
     */
    List<UserBaseInfoVO> getMarkPersonList(Long projectId);

    /**
     * 退出登录
     */
    void logout();

    /**
     * 新增内部用户
     *
     * @param addUserDTO 用户信息
     */
    void addInnerUser(AddInnerUserDTO addUserDTO);

    /**
     * 编辑内部用户
     *
     * @param addUserDTO 用户信息
     */
    void editInnerUser(AddInnerUserDTO addUserDTO, Long userId);

    /**
     * 查询内部用户信息
     *
     * @param account 账号
     * @return InnerUserVO
     */
    InnerUserVO getInnerUserInfo(String account);

    /**
     * 内部用户登录
     *
     * @param request 请求体
     * @return String
     */
    String innerLogin(HttpServletRequest request);

    /**
     * 查询所有内部部门
     *
     * @return 部门列表
     */
    List<DepartmentTreeVO> getAllDeptNotTree();
}
