package cn.sino.mark.service.convert;

import cn.sino.mark.common.model.bo.LabelBO;
import cn.sino.mark.common.model.vo.LabelAllVO;
import cn.sino.mark.common.model.vo.LabelInfoVO;
import cn.sino.mark.common.model.vo.LabelPageVO;
import cn.sino.mark.dao.model.LabelItemDO;
import org.mapstruct.Mapper;
import org.mapstruct.Mapping;
import org.mapstruct.Named;

import java.util.Arrays;
import java.util.List;
import java.util.stream.Collectors;

/**
 * 标签实体转换
 *
 * @author zhangamin
 * @date 2022/8/14
 */
@Mapper(componentModel = "spring")
public interface LabelMapStruct {

    /**
     * LabelBO 转 LabelPageResDTO
     *
     * @param labelBo {@link LabelBO}
     * @return {@link LabelPageVO}
     */
    @Mapping(target = "labelItemNames", qualifiedByName = "stringToList")
    @Mapping(target = "createTime", dateFormat = "yyyy-MM-dd HH:mm:ss")
    LabelPageVO convertToLabelPageVO(LabelBO labelBo);

    /**
     * LabelBO 转 LabelInfoResDTO
     *
     * @param labelBo {@link LabelBO}
     * @return {@link LabelInfoVO}
     */
    @Mapping(source = "labelItems", target = "labelItemNameList", qualifiedByName = "listToList")
    @Mapping(target = "createTime", dateFormat = "yyyy-MM-dd HH:mm:ss")
    LabelInfoVO convertToLabelInfoVO(LabelBO labelBo);

    /**
     * labelBo 转 LabelAllResDTO
     *
     * @param labelBo {@link LabelBO}
     * @return {@link LabelAllVO}
     */
    LabelAllVO convertToLabelAllResDTO(LabelBO labelBo);

    @Named("listToList")
    default List<String> listToList(List<LabelItemDO> labelItems) {
        return labelItems.stream().map(LabelItemDO::getName).collect(Collectors.toList());
    }

    @Named("stringToList")
    default List<String> stringToList(String labelItemNames) {
        return Arrays.asList(labelItemNames.split(","));
    }


}