package cn.sino.mark.service.convert;

import cn.sino.mark.common.config.security.SysUserDetails;
import cn.sino.mark.common.model.bo.SysUserBO;
import cn.sino.mark.common.model.dto.LoginUserDTO;
import cn.sino.mark.common.model.vo.DepartmentTreeVO;
import cn.sino.mark.common.model.vo.LoginUserInfoVO;
import cn.sino.mark.common.model.vo.UserDetailsVO;
import cn.sino.mark.common.model.vo.UserPageVO;
import cn.sino.mark.dao.model.SysDeptDO;
import cn.sino.mark.dao.model.SysUserDO;
import com.github.pagehelper.Page;
import org.mapstruct.Mapper;
import org.mapstruct.Mapping;
import org.mapstruct.factory.Mappers;

/**
 * @author zhangamin
 * @description 后台管理系统用户实体转换类
 * @className cn.sino.coop.service.convert.SysUserMapStruct
 * @date 2022/3/17
 */
@Mapper(componentModel = "spring")
public interface SysUserMapStruct {

    /**
     * 为了在某Filter类中使用，否则不需要此单例
     */
    SysUserMapStruct INSTANCE = Mappers.getMapper(SysUserMapStruct.class);

    /**
     * SysUserDO 转 LoginUserDTO
     *
     * @param sysUserDetails 后台管理系统用户DO
     * @return 登录成功用户DTO
     */
    LoginUserDTO convertToLoginUserDTO(SysUserDetails sysUserDetails);

    /**
     * SysUserDO 转 LoginUserDTO
     *
     * @param sysUser 后台管理系统用户DO
     * @return 登录成功用户DTO
     */
    @Mapping(source = "userId", target = "userId")
    LoginUserDTO convertToLoginUserDTO(SysUserDO sysUser);

    /**
     * SysUserDO 转 SysUserDetails
     *
     * @param sysUser cn.sino.coop.dao.model.SysUserDO
     * @return cn.sino.coop.common.config.security.SysUserDetails
     */
    @Mapping(source = "id", target = "userId")
    SysUserDetails convertToSysUserDetails(SysUserDO sysUser);

    /**
     * SysUserDO 转 UserDetailsVO
     *
     * @param sysUserDO cn.sino.mark.dao.model.SysUserDO
     * @return cn.sino.mark.common.model.vo.UserDetailsVO
     */
    UserDetailsVO convertToUserDetailsVO(SysUserDO sysUserDO);

    Page<UserPageVO> convertToPage(Page<SysUserBO> sysUserBOS);

    UserPageVO convertToUserPageVO(SysUserBO sysUserBO);

    LoginUserInfoVO convertToLoginUserVO(SysUserDO sysUser);

    /**
     * SysDept 转 DepartmentTreeVO
     *
     * @param sysDept {@link SysDeptDO}
     * @return {@link DepartmentTreeVO}
     */
    DepartmentTreeVO convertToDepartmentTreeVO(SysDeptDO sysDept);
}