DROP TABLE IF EXISTS `t_sys_user`;
CREATE TABLE `t_sys_user` (
                              `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT 'PK',
                              `user_id` bigint(20) NOT NULL COMMENT '用户ID',
                              `account` varchar(32) NOT NULL COMMENT '用户账号(用于登录)',
                              `password` varchar(255) NOT NULL COMMENT '用于密码(加密后的)',
                              `user_name` varchar(32) NOT NULL COMMENT '用户姓名',
                              `status` tinyint(1) NOT NULL COMMENT '用户状态(0:正常;1:作废)',
                              `user_type` tinyint(1) NOT NULL COMMENT '用户类型(0:外部员工;1:内部员工)',
                              `is_delete` tinyint(1) NOT NULL COMMENT '是否删除(0:正常;1:已删除)',
                              `create_by` bigint(20) NOT NULL COMMENT '创建人',
                              `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
                              `update_by` bigint(20) NOT NULL COMMENT '更新热',
                              `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
                              PRIMARY KEY (`id`) USING BTREE,
                              UNIQUE KEY `uk_t_sys_user_uid` (`user_id`) USING BTREE,
                              KEY `idx_t_sys_user_account` (`account`) USING BTREE
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COMMENT='系统用户表';

DROP TABLE IF EXISTS `t_sys_role`;
CREATE TABLE `t_sys_role` (
                              `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT 'PK',
                              `role_id` bigint(20) NOT NULL COMMENT '角色ID',
                              `role_name` varchar(30) NOT NULL COMMENT '角色名称',
                              `description` varchar(100) DEFAULT NULL COMMENT '角色描述',
                              `role_code` varchar(32) NOT NULL COMMENT '角色代码(32位UUID)',
                              `is_delete` tinyint(1) NOT NULL COMMENT '是否删除(0:正常;1:删除)',
                              `create_by` bigint(20) NOT NULL COMMENT '创建人',
                              `type` tinyint(1) NOT NULL DEFAULT '0' COMMENT '角色类型(0:外部角色,1:内部角色)',
                              `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
                              `update_by` bigint(20) NOT NULL COMMENT '更新人',
                              `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
                              PRIMARY KEY (`id`) USING BTREE,
                              UNIQUE KEY `uk_t_sys_role_rid` (`role_id`) USING BTREE
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COMMENT='系统角色表';

DROP TABLE IF EXISTS `t_sys_user_role`;
CREATE TABLE `t_sys_user_role` (
                                   `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT 'PK',
                                   `user_id` bigint(20) NOT NULL COMMENT '用户ID',
                                   `role_id` bigint(20) NOT NULL COMMENT '角色ID',
                                   `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
                                   PRIMARY KEY (`id`) USING BTREE,
                                   UNIQUE KEY `uk_t_sys_user_role_uid_rid` (`user_id`,`role_id`) USING BTREE
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COMMENT='系统用户角色表';

DROP TABLE IF EXISTS `t_sys_perm`;
CREATE TABLE `t_sys_perm` (
                              `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT 'PK',
                              `perm_id` bigint(20) NOT NULL COMMENT '角色ID',
                              `perm_name` varchar(30) NOT NULL COMMENT '权限名称',
                              `perm_code` varchar(45) NOT NULL COMMENT '权限代码',
                              `is_menu` tinyint(4) NOT NULL COMMENT '是否是菜单（0：不是；1：是）',
                              `parent_id` bigint(20) NOT NULL COMMENT '父节点ID',
                              `is_default` tinyint(4) NOT NULL COMMENT '是否默认权限(0：不是，1：是)',
                              `sort` bigint(14) NOT NULL COMMENT '排序',
                              `is_delete` tinyint(4) NOT NULL COMMENT '是否删除(0:正常;1:删除)',
                              `create_by` bigint(20) NOT NULL COMMENT '创建人',
                              `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
                              `update_by` bigint(20) NOT NULL COMMENT '更新人',
                              `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
                              PRIMARY KEY (`id`) USING BTREE,
                              UNIQUE KEY `uk_t_sys_perm_pid` (`perm_id`) USING BTREE,
                              KEY `idx_t_sys_perm_pcode` (`perm_code`) USING BTREE
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COMMENT='系统权限表';

DROP TABLE IF EXISTS `t_sys_role_perm`;
CREATE TABLE `t_sys_role_perm` (
                                   `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT 'PK',
                                   `role_id` bigint(20) NOT NULL COMMENT '角色ID',
                                   `perm_id` bigint(20) NOT NULL COMMENT '权限ID',
                                   `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
                                   PRIMARY KEY (`id`) USING BTREE,
                                   UNIQUE KEY `uk_t_sys_role_perm_rid_pid` (`role_id`,`perm_id`) USING BTREE
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COMMENT='系统角色权限表';

DROP TABLE IF EXISTS `t_sys_log`;
CREATE TABLE `t_sys_log` (
                             `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '自增ID，主键',
                             `account` varchar(45) NOT NULL COMMENT '用户账户',
                             `user_name` varchar(45) NOT NULL COMMENT '用户名称',
                             `type` tinyint(4) NOT NULL COMMENT '操作类型(0:登录,1:新增,2:修改,3:删除)',
                             `log` text NOT NULL COMMENT '日志描述',
                             `ip` varchar(15) DEFAULT NULL COMMENT '用户IP地址',
                             `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
                             PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COMMENT='系统操作日志表';

DROP TABLE IF EXISTS `t_category`;
CREATE TABLE `t_category` (
                              `category_id` varchar(255) NOT NULL COMMENT '分类ID',
                              `category_name` varchar(45) NOT NULL COMMENT '分类名称',
                              `parent_category_id` varchar(255) NOT NULL COMMENT '父级分类ID',
                              `is_delete` tinyint(1) NOT NULL COMMENT '是否删除(0:正常;1:已删除)',
                              `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
                              PRIMARY KEY (`category_id`),
                              UNIQUE KEY `uk_t_category_cid` (`category_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='标注分类表';

DROP TABLE IF EXISTS `t_resource`;
CREATE TABLE `t_resource` (
                              `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT 'PK',
                              `resource_id` bigint(20) NOT NULL COMMENT '资源ID',
                              `name` varchar(45) NOT NULL COMMENT '资源名称',
                              `type` tinyint(1) NOT NULL DEFAULT '0' COMMENT '资源类型(0:文本,1:图片,2:视频)',
                              `resource_count` int(10) NOT NULL DEFAULT '0' COMMENT '资源数量',
                              `status` tinyint(1) NOT NULL DEFAULT '0' COMMENT '状态(0:正常;1:作废)',
                              `assign_status` tinyint(1) NOT NULL DEFAULT '0' COMMENT '分配状态(0:未分配,1:已分配)',
                              `is_delete` tinyint(1) NOT NULL DEFAULT '0' COMMENT '是否删除(0:正常;1:已删除)',
                              `create_by` bigint(20) NOT NULL COMMENT '创建人',
                              `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
                              `update_by` bigint(20) NOT NULL COMMENT '更新人',
                              `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
                              PRIMARY KEY (`id`) USING BTREE,
                              UNIQUE KEY `uk_t_resource_id` (`resource_id`) USING BTREE
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COMMENT='资源(数据集)表';

DROP TABLE IF EXISTS `t_resource_data`;
CREATE TABLE `t_resource_data` (
                                   `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT 'PK',
                                   `data_id` bigint(20) NOT NULL COMMENT '资源数据ID',
                                   `resource_id` bigint(20) NOT NULL COMMENT '资源ID',
                                   `content` text DEFAULT NULL COMMENT '文本内容',
                                   `pic_url` varchar(255) DEFAULT NULL COMMENT '图片地址',
                                   `mov_url` varchar(255) DEFAULT NULL COMMENT '视频地址',
                                   `hint` text COMMENT '注释或者参考文本内容',
                                   `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
                                   `is_draft` tinyint(1) NOT NULL DEFAULT '1' COMMENT '草稿状态(0:否,1:是)',
                                   PRIMARY KEY (`id`),
                                   KEY `idx_t_resource_data_rid` (`resource_id`) USING BTREE,
                                   KEY `idx_data_id` (`data_id`)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COMMENT='资源(数据集)数据表';

DROP TABLE IF EXISTS `t_project_group`;
CREATE TABLE `t_project_group` (
                                   `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT 'PK',
                                   `group_id` bigint(20) NOT NULL COMMENT '分组ID',
                                   `name` varchar(45) NOT NULL COMMENT '分组名称',
                                   `status` tinyint(1) NOT NULL COMMENT '状态(0:正常;1:作废)',
                                   `parent_id` bigint(20) NOT NULL COMMENT '父级分组ID',
                                   `is_delete` tinyint(1) NOT NULL COMMENT '是否删除(0:正常;1:已删除)',
                                   `create_by` bigint(20) NOT NULL COMMENT '创建人',
                                   `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
                                   `update_by` bigint(20) NOT NULL COMMENT '更新人',
                                   `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
                                   PRIMARY KEY (`id`),
                                   UNIQUE KEY `uk_t_category_cid` (`group_id`) USING BTREE
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COMMENT='项目分组表';

DROP TABLE IF EXISTS `t_project`;
CREATE TABLE `t_project` (
                             `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT 'PK',
                             `project_id` bigint(20) NOT NULL COMMENT '项目id',
                             `name` varchar(45) NOT NULL COMMENT '项目名称',
                             `description` varchar(500) DEFAULT NULL COMMENT '项目描述',
                             `begin_time` datetime NOT NULL COMMENT '有效期开始时间',
                             `end_time` datetime NOT NULL COMMENT '有效期结束时间',
                             `push_time` datetime NOT NULL COMMENT '推送时间',
                             `complete_time` datetime DEFAULT NULL COMMENT '完成日期',
                             `status` tinyint(1) NOT NULL DEFAULT '0' COMMENT '状态(0:草稿状态,1:正式状态)',
                             `group_id` bigint(20) NOT NULL COMMENT '分组ID',
                             `is_delete` tinyint(1) NOT NULL COMMENT '是否删除(0:正常;1:已删除)',
                             `create_by` bigint(20) NOT NULL COMMENT '创建人',
                             `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
                             `update_by` bigint(20) NOT NULL COMMENT '更新人',
                             `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
                             PRIMARY KEY (`id`),
                             UNIQUE KEY `uk_t_project_id` (`project_id`),
                             KEY `idx_t_project_group_id` (`group_id`) USING BTREE
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `t_project_category`;
CREATE TABLE `t_project_category` (
                                      `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT 'PK',
                                      `project_id` bigint(20) NOT NULL COMMENT '项目ID',
                                      `category_id` varchar(255) NOT NULL COMMENT '项目分类',
                                      `category_snapshot` text NOT NULL COMMENT '分类快照',
                                      `is_delete` tinyint(1) NOT NULL COMMENT '是否删除(0:正常;1:已删除)',
                                      `create_by` bigint(20) NOT NULL COMMENT '创建人',
                                      `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
                                      `update_by` bigint(20) NOT NULL COMMENT '更新人',
                                      `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
                                      PRIMARY KEY (`id`),
                                      KEY `idx_t_project_category_pid` (`project_id`) USING BTREE
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `t_project_resource`;
CREATE TABLE `t_project_resource` (
                                      `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT 'PK',
                                      `project_id` bigint(20) NOT NULL COMMENT '项目ID',
                                      `resource_id` bigint(20) NOT NULL COMMENT '资源ID',
                                      `is_delete` tinyint(1) NOT NULL COMMENT '是否删除(0:正常;1:已删除)',
                                      `create_by` bigint(20) NOT NULL COMMENT '创建人',
                                      `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
                                      `update_by` bigint(20) NOT NULL COMMENT '更新人',
                                      `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
                                      PRIMARY KEY (`id`) USING BTREE,
                                      KEY `t_project_resource_rid` (`resource_id`) USING BTREE
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COMMENT='项目资源表';

DROP TABLE IF EXISTS `t_project_user`;
CREATE TABLE `t_project_user` (
                                  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT 'PK',
                                  `project_id` bigint(20) NOT NULL COMMENT '项目ID',
                                  `user_id` bigint(20) NOT NULL COMMENT '用户ID',
                                  `is_delete` tinyint(1) NOT NULL COMMENT '是否删除(0:正常;1:已删除)',
                                  `create_by` bigint(20) NOT NULL COMMENT '创建人',
                                  `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
                                  `update_by` bigint(20) NOT NULL COMMENT '更新人',
                                  `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
                                  PRIMARY KEY (`id`) USING BTREE,
                                  KEY `t_project_resource_rid` (`user_id`) USING BTREE
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COMMENT='项目用户表';

DROP TABLE IF EXISTS `t_project_task`;
CREATE TABLE `t_project_task` (
                                  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT 'PK',
                                  `task_id` bigint(20) NOT NULL COMMENT '任务id',
                                  `project_id` bigint(20) NOT NULL COMMENT '项目ID',
                                  `name` varchar(50) NOT NULL COMMENT '任务名称',
                                  `user_id` bigint(20) NOT NULL COMMENT '用户ID',
                                  `account` varchar(32) NOT NULL COMMENT '用户账户',
                                  `type` tinyint(1) NOT NULL DEFAULT '0' COMMENT '资源类型(0:文本,1:图片,2:视频)',
                                  `task_count` int(10) NOT NULL COMMENT '任务数量',
                                  `begin_time` datetime NOT NULL COMMENT '有效期开始时间',
                                  `end_time` datetime NOT NULL COMMENT '有效期结束日期',
                                  `complete_time` datetime DEFAULT NULL COMMENT '完成时间',
                                  `is_complete` tinyint(1) NOT NULL DEFAULT '0' COMMENT '是否完成(0:未完成,1:已完成)',
                                  `mark_num` int(10) DEFAULT '0' COMMENT '标注数量',
                                  `problem_num` int(10) DEFAULT '0' COMMENT '存疑数量',
                                  `ignore_num` int(10) DEFAULT '0' COMMENT '忽略数量',
                                  `success_num` int(10) DEFAULT '0' COMMENT '验证成功数量',
                                  `failed_num` int(10) DEFAULT '0' COMMENT '验证失败数量',
                                  `is_delete` tinyint(1) NOT NULL DEFAULT '0' COMMENT '是否删除(0:正常;1:已删除)',
                                  `create_by` bigint(20) NOT NULL COMMENT '创建人',
                                  `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
                                  `update_by` bigint(20) NOT NULL COMMENT '更新人',
                                  `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
                                  PRIMARY KEY (`id`),
                                  KEY `idx_t_project_task_pid` (`project_id`) USING BTREE,
                                  KEY `idx_t_project_task_uid` (`user_id`) USING BTREE
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `t_project_task_detail`;
CREATE TABLE `t_project_task_detail` (
                                         `id` bigint(20) NOT NULL COMMENT 'PK',
                                         `detail_id` bigint(20) NOT NULL COMMENT '任务明细id',
                                         `project_id` bigint(20) NOT NULL COMMENT '项目ID',
                                         `task_id` bigint(20) NOT NULL COMMENT '任务ID',
                                         `data_id` bigint(20) NOT NULL COMMENT '资源数据ID',
                                         `category_id` varchar(45) DEFAULT NULL COMMENT '打标分类ID',
                                         `category_ids` text COMMENT '分类集合',
                                         `type` tinyint(1) NOT NULL DEFAULT '0' COMMENT '类型(0:打标,1:忽略)',
                                         `has_problem` tinyint(1) NOT NULL DEFAULT '0' COMMENT '是否存疑(0:否,1:是)',
                                         `mark_user_id` bigint(20) DEFAULT NULL COMMENT '打标人ID',
                                         `is_mark` tinyint(1) NOT NULL DEFAULT '0' COMMENT '是否标记(0:未标记,1:已标记)',
                                         `mark_time` datetime DEFAULT NULL COMMENT '操作时间(打标，忽略，存疑)',
                                         `sample_type` tinyint(1) NOT NULL DEFAULT '0' COMMENT '抽样类型(0:未抽样,1：验证成功，2：验证失败)',
                                         `sample_desc` varchar(100) DEFAULT NULL COMMENT '验证说明',
                                         `sample_time` datetime DEFAULT NULL COMMENT '抽样验证时间',
                                         `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
                                         PRIMARY KEY (`id`),
                                         UNIQUE KEY `uk_t_project_task_detail_pid` (`project_id`,`task_id`,`data_id`) USING BTREE,
                                         KEY `idx_data_id` (`data_id`) COMMENT '资源数据id索引',
                                         KEY `idx_task_id` (`task_id`) COMMENT '任务id索引',
                                         KEY `idx_project_id` (`project_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='项目任务明细表';

INSERT INTO `t_sys_role` (`id`, `role_id`, `role_name`, `description`, `role_code`, `is_delete`, `create_by`, `type`, `create_time`, `update_by`, `update_time`) VALUES ('1', '1', '超级管理员', NULL, 'Administrator', '0', '0', '0', '2020-11-29 00:00:00', '0', '2020-11-29 00:00:00');
INSERT INTO `t_sys_role` (`id`, `role_id`, `role_name`, `description`, `role_code`, `is_delete`, `create_by`, `type`, `create_time`, `update_by`, `update_time`) VALUES ('2', '2', '人员管理负责人', NULL, 'UserManager', '0', '1', '0', '2022-03-29 19:35:20', '1', '2022-04-06 19:34:52');
INSERT INTO `t_sys_role` (`id`, `role_id`, `role_name`, `description`, `role_code`, `is_delete`, `create_by`, `type`, `create_time`, `update_by`, `update_time`) VALUES ('3', '3', '任务分配负责人', NULL, 'TaskManager', '0', '1', '0', '2022-03-29 19:36:06', '1', '2022-04-06 19:34:45');
INSERT INTO `t_sys_role` (`id`, `role_id`, `role_name`, `description`, `role_code`, `is_delete`, `create_by`, `type`, `create_time`, `update_by`, `update_time`) VALUES ('4', '4', '分类管理负责人', NULL, 'CategoryManager', '0', '1', '0', '2022-04-06 19:34:33', '1', '2022-04-06 19:34:33');
INSERT INTO `t_sys_role` (`id`, `role_id`, `role_name`, `description`, `role_code`, `is_delete`, `create_by`, `type`, `create_time`, `update_by`, `update_time`) VALUES ('5', '5', '资源管理负责人', NULL, 'ResourceManager', '0', '1', '0', '2022-04-06 19:35:18', '1', '2022-04-06 19:35:18');
INSERT INTO `t_sys_role` (`id`, `role_id`, `role_name`, `description`, `role_code`, `is_delete`, `create_by`, `type`, `create_time`, `update_by`, `update_time`) VALUES ('6', '6', '标注员(内部)', NULL, 'InnerMarkPerson', '0', '1', '0', '2022-04-06 19:36:00', '1', '2022-04-06 19:36:00');
INSERT INTO `t_sys_role` (`id`, `role_id`, `role_name`, `description`, `role_code`, `is_delete`, `create_by`, `type`, `create_time`, `update_by`, `update_time`) VALUES ('7', '7', '标注员(外部)', NULL, 'OuterMarkPerson', '0', '1', '0', '2022-04-06 19:36:26', '1', '2022-04-06 19:36:26');


INSERT INTO `t_sys_perm` (`id`, `perm_id`, `perm_name`, `perm_code`, `is_menu`, `parent_id`, `is_default`, `sort`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES ('1', '650296443013173248', '系统管理', 'system-management', '1', '0', '0', '1608462072534', '0', '0', '2020-11-29 19:25:54', '0', '2020-12-20 19:01:18');
INSERT INTO `t_sys_perm` (`id`, `perm_id`, `perm_name`, `perm_code`, `is_menu`, `parent_id`, `is_default`, `sort`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES ('2', '650296516384133120', '用户管理', 'user-management', '1', '650296443013173248', '0', '1606649171431', '0', '0', '2020-11-29 19:26:11', '0', '2020-12-08 22:49:35');
INSERT INTO `t_sys_perm` (`id`, `perm_id`, `perm_name`, `perm_code`, `is_menu`, `parent_id`, `is_default`, `sort`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES ('6', '650297337213620224', '新增外部用户按钮', 'add-outer-user-btn', '0', '650296516384133120', '0', '1606649367132', '0', '0', '2020-11-29 19:29:27', '0', '2022-04-18 16:05:16');
INSERT INTO `t_sys_perm` (`id`, `perm_id`, `perm_name`, `perm_code`, `is_menu`, `parent_id`, `is_default`, `sort`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES ('7', '650297517342199808', '编辑外部用户按钮', 'modify-outer-user-btn', '0', '650296516384133120', '0', '1606649410078', '0', '0', '2020-11-29 19:30:10', '0', '2022-04-18 16:05:37');
INSERT INTO `t_sys_perm` (`id`, `perm_id`, `perm_name`, `perm_code`, `is_menu`, `parent_id`, `is_default`, `sort`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES ('12', '650298079479599104', '删除用户按钮', 'delete-user-btn', '0', '650296516384133120', '0', '1606649544102', '0', '0', '2020-11-29 19:32:24', '0', '2022-04-18 16:06:41');
INSERT INTO `t_sys_perm` (`id`, `perm_id`, `perm_name`, `perm_code`, `is_menu`, `parent_id`, `is_default`, `sort`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES ('23', '826434012540047360', '新增外部用户页面', 'add-user-page', '0', '650296516384133120', '0', '1648643622988', '0', '1', '2022-03-30 20:33:43', '1', '2022-03-30 20:51:39');
INSERT INTO `t_sys_perm` (`id`, `perm_id`, `perm_name`, `perm_code`, `is_menu`, `parent_id`, `is_default`, `sort`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES ('24', '826449149393113088', '编辑外部用户页面', 'edit-user-page', '0', '650296516384133120', '0', '1648647231896', '0', '1', '2022-03-30 21:33:52', '1', '2022-03-30 21:33:54');
INSERT INTO `t_sys_perm` (`id`, `perm_id`, `perm_name`, `perm_code`, `is_menu`, `parent_id`, `is_default`, `sort`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES ('25', '830340082819928064', '分类管理', 'category-management', '1', '0', '0', '1649574902713', '0', '1', '2022-04-10 15:15:03', '1', '2022-04-10 15:15:05');
INSERT INTO `t_sys_perm` (`id`, `perm_id`, `perm_name`, `perm_code`, `is_menu`, `parent_id`, `is_default`, `sort`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES ('26', '830340315381501952', '分类设置', 'category-management-page', '0', '830340082819928064', '0', '1649574958164', '0', '1', '2022-04-10 15:15:58', '1', '2022-04-10 15:16:01');
INSERT INTO `t_sys_perm` (`id`, `perm_id`, `perm_name`, `perm_code`, `is_menu`, `parent_id`, `is_default`, `sort`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES ('27', '830340401729638400', '资源管理', 'resource-management', '1', '0', '0', '1649574978751', '0', '1', '2022-04-10 15:16:19', '1', '2022-04-10 15:16:21');
INSERT INTO `t_sys_perm` (`id`, `perm_id`, `perm_name`, `perm_code`, `is_menu`, `parent_id`, `is_default`, `sort`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES ('28', '830340480981012480', '资源设置', 'resource-management-page', '0', '830340401729638400', '0', '1649574997646', '0', '1', '2022-04-10 15:16:38', '1', '2022-04-10 15:16:40');
INSERT INTO `t_sys_perm` (`id`, `perm_id`, `perm_name`, `perm_code`, `is_menu`, `parent_id`, `is_default`, `sort`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES ('29', '830340544130453504', '新增资源', 'add-resource-page', '0', '830340401729638400', '0', '1649575012702', '0', '1', '2022-04-10 15:16:53', '1', '2022-04-10 15:16:55');
INSERT INTO `t_sys_perm` (`id`, `perm_id`, `perm_name`, `perm_code`, `is_menu`, `parent_id`, `is_default`, `sort`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES ('30', '830340614443765760', '任务资源分配', 'task-assign-management', '1', '0', '0', '1649575029466', '0', '1', '2022-04-10 15:17:09', '1', '2022-04-10 15:17:12');
INSERT INTO `t_sys_perm` (`id`, `perm_id`, `perm_name`, `perm_code`, `is_menu`, `parent_id`, `is_default`, `sort`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES ('31', '830340683473620992', '项目管理', 'project-management-page', '0', '830340614443765760', '0', '1649575045924', '0', '1', '2022-04-10 15:17:26', '1', '2022-04-10 15:17:28');
INSERT INTO `t_sys_perm` (`id`, `perm_id`, `perm_name`, `perm_code`, `is_menu`, `parent_id`, `is_default`, `sort`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES ('33', '830340803632041984', '项目组维护', 'group-management-page', '0', '830340614443765760', '0', '1649575074572', '0', '1', '2022-04-10 15:17:55', '1', '2022-04-10 15:17:57');
INSERT INTO `t_sys_perm` (`id`, `perm_id`, `perm_name`, `perm_code`, `is_menu`, `parent_id`, `is_default`, `sort`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES ('34', '830340925623373824', '新增项目', 'add-project-page', '0', '830340614443765760', '0', '1649575103657', '0', '1', '2022-04-10 15:18:24', '1', '2022-04-10 15:18:26');
INSERT INTO `t_sys_perm` (`id`, `perm_id`, `perm_name`, `perm_code`, `is_menu`, `parent_id`, `is_default`, `sort`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES ('35', '830340981550223360', '任务列表', 'task-management-page', '0', '830340614443765760', '0', '1649575116991', '0', '1', '2022-04-10 15:18:37', '1', '2022-04-10 15:18:39');
INSERT INTO `t_sys_perm` (`id`, `perm_id`, `perm_name`, `perm_code`, `is_menu`, `parent_id`, `is_default`, `sort`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES ('37', '830341088320425984', '抽样任务列表', 'sample-task-page', '0', '830340614443765760', '0', '1649575142447', '0', '1', '2022-04-10 15:19:02', '1', '2022-04-10 15:19:05');
INSERT INTO `t_sys_perm` (`id`, `perm_id`, `perm_name`, `perm_code`, `is_menu`, `parent_id`, `is_default`, `sort`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES ('38', '830341151830577152', '任务抽样验证', 'sample-mark-page', '0', '830340614443765760', '0', '1649575157589', '0', '1', '2022-04-10 15:19:18', '1', '2022-04-10 15:19:20');
INSERT INTO `t_sys_perm` (`id`, `perm_id`, `perm_name`, `perm_code`, `is_menu`, `parent_id`, `is_default`, `sort`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES ('39', '830794921660125184', '我的任务', 'my-task-management', '1', '0', '0', '1649683344745', '0', '1', '2022-04-11 21:22:25', '1', '2022-04-11 21:22:26');
INSERT INTO `t_sys_perm` (`id`, `perm_id`, `perm_name`, `perm_code`, `is_menu`, `parent_id`, `is_default`, `sort`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES ('40', '830795255237316608', '标注结果查询', 'mark-result-management', '1', '0', '0', '1649683424278', '0', '1', '2022-04-11 21:23:44', '1', '2022-04-11 21:23:45');
INSERT INTO `t_sys_perm` (`id`, `perm_id`, `perm_name`, `perm_code`, `is_menu`, `parent_id`, `is_default`, `sort`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES ('41', '830795357175681024', '我的任务页面', 'my-task-page', '0', '830794921660125184', '0', '1649683448582', '0', '1', '2022-04-11 21:24:09', '1', '2022-04-11 21:24:10');
INSERT INTO `t_sys_perm` (`id`, `perm_id`, `perm_name`, `perm_code`, `is_menu`, `parent_id`, `is_default`, `sort`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES ('42', '830795435718217728', '标注结果查询页面', 'mark-result-page', '0', '830795255237316608', '0', '1649683467308', '0', '1', '2022-04-11 21:24:27', '1', '2022-04-11 21:24:29');
INSERT INTO `t_sys_perm` (`id`, `perm_id`, `perm_name`, `perm_code`, `is_menu`, `parent_id`, `is_default`, `sort`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES ('44', '833250630431674368', '新增子分类按钮', 'add-child-category-btn', '0', '830340082819928064', '0', '1650268831343', '0', '1', '2022-04-18 16:00:31', '1', '2022-04-18 16:00:34');
INSERT INTO `t_sys_perm` (`id`, `perm_id`, `perm_name`, `perm_code`, `is_menu`, `parent_id`, `is_default`, `sort`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES ('45', '833250711469821952', '修改分类按钮', 'modify-category-btn', '0', '830340082819928064', '0', '1650268850664', '0', '1', '2022-04-18 16:00:51', '1', '2022-04-18 16:00:53');
INSERT INTO `t_sys_perm` (`id`, `perm_id`, `perm_name`, `perm_code`, `is_menu`, `parent_id`, `is_default`, `sort`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES ('46', '833250766654279680', '删除分类按钮', 'delete-category-btn', '0', '830340082819928064', '0', '1650268863821', '0', '1', '2022-04-18 16:01:04', '1', '2022-04-18 16:01:06');
INSERT INTO `t_sys_perm` (`id`, `perm_id`, `perm_name`, `perm_code`, `is_menu`, `parent_id`, `is_default`, `sort`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES ('47', '833251048691863552', '新增资源按钮', 'add-resource-btn', '0', '830340401729638400', '0', '1650268931064', '0', '1', '2022-04-18 16:02:11', '1', '2022-04-18 16:02:14');
INSERT INTO `t_sys_perm` (`id`, `perm_id`, `perm_name`, `perm_code`, `is_menu`, `parent_id`, `is_default`, `sort`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES ('48', '833251098939625472', '删除资源按钮', 'delete-resource-btn', '0', '830340401729638400', '0', '1650268943044', '0', '1', '2022-04-18 16:02:23', '1', '2022-04-18 16:02:26');
INSERT INTO `t_sys_perm` (`id`, `perm_id`, `perm_name`, `perm_code`, `is_menu`, `parent_id`, `is_default`, `sort`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES ('49', '833251200190124032', '新增项目分组按钮', 'add-group-btn', '0', '830340614443765760', '0', '1650268967184', '0', '1', '2022-04-18 16:02:47', '1', '2022-04-18 16:02:50');
INSERT INTO `t_sys_perm` (`id`, `perm_id`, `perm_name`, `perm_code`, `is_menu`, `parent_id`, `is_default`, `sort`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES ('50', '833251289361027072', '新增项目按钮', 'add-project-btn', '0', '830340614443765760', '0', '1650268988444', '0', '1', '2022-04-18 16:03:08', '1', '2022-04-18 16:03:11');
INSERT INTO `t_sys_perm` (`id`, `perm_id`, `perm_name`, `perm_code`, `is_menu`, `parent_id`, `is_default`, `sort`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES ('51', '833251377445605376', '删除项目按钮', 'delete-project-btn', '0', '830340614443765760', '0', '1650269009445', '0', '1', '2022-04-18 16:03:29', '1', '2022-04-18 16:03:32');
INSERT INTO `t_sys_perm` (`id`, `perm_id`, `perm_name`, `perm_code`, `is_menu`, `parent_id`, `is_default`, `sort`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES ('53', '833251493711712256', '重新指派按钮', 'reassign-btn', '0', '830340614443765760', '0', '1650269037165', '0', '1', '2022-04-18 16:03:57', '1', '2022-04-18 16:04:00');
INSERT INTO `t_sys_perm` (`id`, `perm_id`, `perm_name`, `perm_code`, `is_menu`, `parent_id`, `is_default`, `sort`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES ('54', '833251549990883328', '验证按钮', 'check-btn', '0', '830340614443765760', '0', '1650269050583', '0', '1', '2022-04-18 16:04:11', '1', '2022-04-18 16:04:13');
INSERT INTO `t_sys_perm` (`id`, `perm_id`, `perm_name`, `perm_code`, `is_menu`, `parent_id`, `is_default`, `sort`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES ('55', '833252253409218560', '新增内部用户按钮 ', 'add-inner-user-btn', '0', '650296516384133120', '0', '1650269218291', '0', '1', '2022-04-18 16:06:58', '1', '2022-04-18 16:07:01');
INSERT INTO `t_sys_perm` (`id`, `perm_id`, `perm_name`, `perm_code`, `is_menu`, `parent_id`, `is_default`, `sort`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES ('56', '833252313417125888', '编辑内部用户按钮', 'modify-inner-user-btn', '0', '650296516384133120', '0', '1650269232598', '0', '1', '2022-04-18 16:07:13', '1', '2022-04-18 16:07:15');
INSERT INTO `t_sys_perm` (`id`, `perm_id`, `perm_name`, `perm_code`, `is_menu`, `parent_id`, `is_default`, `sort`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES ('57', '833947291160154112', '修改项目页面', 'edit-project-page', '0', '830340614443765760', '0', '1650434928202', '0', '1', '2022-04-20 14:08:48', '1', '2022-04-20 14:08:50');
INSERT INTO `t_sys_perm` (`id`, `perm_id`, `perm_name`, `perm_code`, `is_menu`, `parent_id`, `is_default`, `sort`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES ('58', '833947502821511168', '修改项目按钮', 'edit-project-btn', '0', '830340614443765760', '0', '1650434978668', '0', '1', '2022-04-20 14:09:39', '1', '2022-04-20 14:09:41');
INSERT INTO `t_sys_perm` (`id`, `perm_id`, `perm_name`, `perm_code`, `is_menu`, `parent_id`, `is_default`, `sort`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES ('59', '834033076530057216', '解析资源按钮', 'analyse-resource-btn', '0', '830340401729638400', '0', '1650455381028', '0', '1', '2022-04-20 19:49:41', '1', '2022-04-20 19:49:44');
INSERT INTO `t_sys_perm` (`id`, `perm_id`, `perm_name`, `perm_code`, `is_menu`, `parent_id`, `is_default`, `sort`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES ('60', '834033175532408832', '上传资源按钮', 'import-resource-btn', '0', '830340401729638400', '0', '1650455404634', '0', '1', '2022-04-20 19:50:05', '1', '2022-04-20 19:50:08');
INSERT INTO `t_sys_perm` (`id`, `perm_id`, `perm_name`, `perm_code`, `is_menu`, `parent_id`, `is_default`, `sort`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES ('61', '834034369776586752', '修改项目组按钮', 'modify-group-btn', '0', '830340614443765760', '0', '1650455689364', '0', '1', '2022-04-20 19:54:49', '1', '2022-04-20 19:54:52');
INSERT INTO `t_sys_perm` (`id`, `perm_id`, `perm_name`, `perm_code`, `is_menu`, `parent_id`, `is_default`, `sort`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES ('62', '834034505848197120', '删除项目组按钮', 'delete-group-btn', '0', '830340614443765760', '0', '1650455721806', '0', '1', '2022-04-20 19:55:22', '1', '2022-04-20 19:55:25');
INSERT INTO `t_sys_perm` (`id`, `perm_id`, `perm_name`, `perm_code`, `is_menu`, `parent_id`, `is_default`, `sort`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES ('64', '835452961193725952', '任务标注页面', 'mark-page', '0', '830340614443765760', '0', '1650793907913', '0', '1', '2022-04-24 17:51:48', '1', '2022-04-24 17:51:47');
INSERT INTO `t_sys_perm` (`id`, `perm_id`, `perm_name`, `perm_code`, `is_menu`, `parent_id`, `is_default`, `sort`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES ('65', '835453206208188416', '标注按钮', 'mark-btn', '0', '830340614443765760', '0', '1650793966330', '0', '1', '2022-04-24 17:52:46', '1', '2022-04-24 17:52:46');
INSERT INTO `t_sys_perm` (`id`, `perm_id`, `perm_name`, `perm_code`, `is_menu`, `parent_id`, `is_default`, `sort`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES ('66', '836215705845108736', '新增内部用户页面', 'add-inner-user-page', '0', '650296516384133120', '0', '1650975760406', '0', '1', '2022-04-26 20:22:40', '1', '2022-04-26 20:22:40');
INSERT INTO `t_sys_perm` (`id`, `perm_id`, `perm_name`, `perm_code`, `is_menu`, `parent_id`, `is_default`, `sort`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES ('67', '836215814301421568', '编辑内部用户页面', 'edit-inner-user-page', '0', '650296516384133120', '0', '1650975786267', '0', '1', '2022-04-26 20:23:06', '1', '2022-04-26 20:23:06');


INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('118', '4', '830340082819928064', '2022-04-18 16:53:26');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('119', '4', '830340315381501952', '2022-04-18 16:53:26');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('120', '4', '833250565575151616', '2022-04-18 16:53:26');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('121', '4', '833250630431674368', '2022-04-18 16:53:26');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('122', '4', '833250711469821952', '2022-04-18 16:53:26');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('123', '4', '833250766654279680', '2022-04-18 16:53:26');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('181', '5', '830340401729638400', '2022-04-20 20:07:13');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('182', '5', '830340480981012480', '2022-04-20 20:07:13');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('183', '5', '830340544130453504', '2022-04-20 20:07:13');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('184', '5', '833251048691863552', '2022-04-20 20:07:13');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('185', '5', '833251098939625472', '2022-04-20 20:07:13');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('186', '5', '834033076530057216', '2022-04-20 20:07:13');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('187', '5', '834033175532408832', '2022-04-20 20:07:13');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('256', '7', '830340614443765760', '2022-04-24 17:53:28');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('257', '7', '835452961193725952', '2022-04-24 17:53:28');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('258', '7', '835453206208188416', '2022-04-24 17:53:28');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('259', '7', '830794921660125184', '2022-04-24 17:53:28');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('260', '7', '830795357175681024', '2022-04-24 17:53:28');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('261', '6', '830340082819928064', '2022-04-24 17:53:55');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('262', '6', '830340315381501952', '2022-04-24 17:53:55');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('263', '6', '830340614443765760', '2022-04-24 17:53:55');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('264', '6', '835452961193725952', '2022-04-24 17:53:55');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('265', '6', '835453206208188416', '2022-04-24 17:53:55');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('266', '6', '830794921660125184', '2022-04-24 17:53:55');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('267', '6', '830795357175681024', '2022-04-24 17:53:55');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('268', '3', '830340614443765760', '2022-04-24 17:54:05');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('269', '3', '830340683473620992', '2022-04-24 17:54:05');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('270', '3', '830340803632041984', '2022-04-24 17:54:05');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('271', '3', '830340925623373824', '2022-04-24 17:54:05');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('272', '3', '830340981550223360', '2022-04-24 17:54:05');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('273', '3', '830341088320425984', '2022-04-24 17:54:05');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('274', '3', '830341151830577152', '2022-04-24 17:54:05');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('275', '3', '833251200190124032', '2022-04-24 17:54:05');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('276', '3', '833251289361027072', '2022-04-24 17:54:05');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('277', '3', '833251377445605376', '2022-04-24 17:54:05');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('278', '3', '833251493711712256', '2022-04-24 17:54:05');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('279', '3', '833251549990883328', '2022-04-24 17:54:05');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('280', '3', '833947291160154112', '2022-04-24 17:54:05');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('281', '3', '833947502821511168', '2022-04-24 17:54:05');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('282', '3', '834034369776586752', '2022-04-24 17:54:05');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('283', '3', '834034505848197120', '2022-04-24 17:54:05');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('284', '3', '835452961193725952', '2022-04-24 17:54:05');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('285', '3', '835453206208188416', '2022-04-24 17:54:05');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('286', '2', '650296443013173248', '2022-04-26 20:23:17');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('287', '2', '650296516384133120', '2022-04-26 20:23:17');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('288', '2', '650297337213620224', '2022-04-26 20:23:17');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('289', '2', '650297517342199808', '2022-04-26 20:23:17');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('290', '2', '650298079479599104', '2022-04-26 20:23:17');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('291', '2', '826434012540047360', '2022-04-26 20:23:17');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('292', '2', '826449149393113088', '2022-04-26 20:23:17');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('293', '2', '833252253409218560', '2022-04-26 20:23:17');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('294', '2', '833252313417125888', '2022-04-26 20:23:17');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('295', '2', '836215705845108736', '2022-04-26 20:23:17');
INSERT INTO `t_sys_role_perm` (`id`, `role_id`, `perm_id`, `create_time`) VALUES ('296', '2', '836215814301421568', '2022-04-26 20:23:17');


--测试用数据
--超管账号 因测试,暂时设为外部人员  密码: 000000
INSERT INTO `t_sys_user` (`id`, `user_id`, `account`, `password`, `user_name`, `status`, `user_type`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES ('1', '1', 'daniel.kang', '$2a$10$nnxmiOoR9UV6O.ndbx4OWusxm0XqiWGc9ZG5Dp1fSTFAXqYD8/K12', '超级管理员', '0', '1', '0', '0', '2020-11-29 00:00:00', '0', '2022-04-19 17:43:15');

INSERT INTO `t_sys_user_role` (`id`, `user_id`, `role_id`, `create_time`) VALUES ('1', '1', '1', '2020-12-08 22:49:38');



ALTER TABLE `t_resource_data`
    MODIFY COLUMN `content`  text CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci NULL COMMENT '文本内容',
    MODIFY COLUMN `hint`  text CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci NULL COMMENT '注释或者参考文本内容';