CREATE TABLE `t_label` (
 `id` bigint(20) NOT NULL COMMENT 'PK',
 `name` varchar(45) NOT NULL COMMENT '标签名称',
 `is_delete` tinyint(4) NOT NULL COMMENT '是否删除(0:正常;1:已删除)',
 `create_by` bigint(20) NOT NULL COMMENT '创建人',
 `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
 `update_by` bigint(20) NOT NULL COMMENT '更新人',
 `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
 PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=COMPACT COMMENT='标签表';

CREATE TABLE `t_label_item` (
  `id` int(10) NOT NULL AUTO_INCREMENT COMMENT 'PK',
  `label_id` bigint(20) NOT NULL COMMENT '标签ID',
  `name` varchar(10) NOT NULL COMMENT '标签选项名称',
  `sort` bigint(20) NOT NULL COMMENT '排序(时间戳)',
  `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  PRIMARY KEY (`id`) USING BTREE,
  KEY `idx_label_id` (`label_id`) USING BTREE
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 ROW_FORMAT=COMPACT COMMENT='标签选项表';

ALTER TABLE `t_resource`
    MODIFY COLUMN `type` tinyint(1) NOT NULL DEFAULT 0 COMMENT '资源类型(0:文本,1:图片,2:视频,3:链接)' AFTER `name`;


CREATE TABLE `t_sys_dept` (
    `id` bigint(20) NOT NULL COMMENT '部门ID，主键',
    `name` varchar(32) NOT NULL COMMENT '部门名称',
    `description` varchar(128) DEFAULT NULL COMMENT '部门描述',
    `parent_id` bigint(11) NOT NULL COMMENT '上级部门id',
    `sort` bigint(20) NOT NULL COMMENT '排序字段',
    `level` int(11) DEFAULT '0' COMMENT '部门等级（1:一级部门 2:二级部门 3:三级部门。。）',
    `is_delete` tinyint(4) NOT NULL COMMENT '是否删除(0:正常;1:删除)',
    `create_by` bigint(20) NOT NULL COMMENT '创建人',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '部门创建时间',
    `update_by` bigint(20) NOT NULL COMMENT '更新人',
    `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '部门更新时间',
    PRIMARY KEY (`id`) USING BTREE,
    KEY `idx_parent_id` (`parent_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='系统部门表';

INSERT INTO `t_sys_dept` (`id`, `name`, `description`, `parent_id`, `sort`, `level`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES (1, '算法部门', NULL, 0, 1662279502530, 1, 0, 1, '2022-09-04 16:18:23', 1, '2022-09-04 16:18:23');
INSERT INTO `t_sys_dept` (`id`, `name`, `description`, `parent_id`, `sort`, `level`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES (2, '业务部门', NULL, 0, 1662279502531, 1, 0, 1, '2022-09-04 16:18:24', 1, '2022-09-04 16:18:24');

ALTER TABLE `t_sys_user` ADD COLUMN `dept_id` bigint(20) NOT NULL DEFAULT 0 COMMENT '用户部门' AFTER `user_type`;

UPDATE t_sys_user SET dept_id = 1 where user_type = 1;

INSERT INTO `t_sys_role` (`id`, `role_id`, `role_name`, `description`, `role_code`, `is_delete`, `create_by`, `type`, `create_time`, `update_by`, `update_time`) VALUES (8, 8, '标签配置负责人', NULL, 'LabelManagement', 0, 1, 0, '2022-09-14 19:36:26', 1, '2022-09-14 19:36:26');
INSERT INTO `t_sys_perm` (`perm_id`, `perm_name`, `perm_code`, `is_menu`, `parent_id`, `is_default`, `sort`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES (1559741406246449154, '标签管理', 'label-management', 1, 0, 0, 1606649153931, 0, 1, '2022-09-14 11:18:25', 1, '2022-09-14 14:56:59');
INSERT INTO `t_sys_perm` (`perm_id`, `perm_name`, `perm_code`, `is_menu`, `parent_id`, `is_default`, `sort`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES (1560465858399625218, '添加标签', 'add-label', 0, 1559741406246449154, 0, 1660879027350, 0, 1, '2022-09-14 11:17:07', 1, '2022-09-14 11:17:07');
INSERT INTO `t_sys_perm` (`perm_id`, `perm_name`, `perm_code`, `is_menu`, `parent_id`, `is_default`, `sort`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES (1560465901403824130, '编辑标签', 'edit-label', 0, 1559741406246449154, 0, 1660879037606, 0, 1, '2022-09-14 11:17:18', 1, '2022-09-14 11:17:18');
INSERT INTO `t_sys_perm` (`perm_id`, `perm_name`, `perm_code`, `is_menu`, `parent_id`, `is_default`, `sort`, `is_delete`, `create_by`, `create_time`, `update_by`, `update_time`) VALUES (1560465951827746818, '删除标签', 'delete-label', 0, 1559741406246449154, 0, 1660879049632, 0, 1, '2022-09-14 11:17:30', 1, '2022-09-14 11:17:30');
INSERT INTO `t_sys_role_perm` (`role_id`, `perm_id`, `create_time`) VALUES (8, 1559741406246449154, '2022-09-14 16:53:26');
INSERT INTO `t_sys_role_perm` (`role_id`, `perm_id`, `create_time`) VALUES (8, 1560465858399625218, '2022-09-14 16:53:27');
INSERT INTO `t_sys_role_perm` (`role_id`, `perm_id`, `create_time`) VALUES (8, 1560465901403824130, '2022-09-14 16:53:28');
INSERT INTO `t_sys_role_perm` (`role_id`, `perm_id`, `create_time`) VALUES (8, 1560465951827746818, '2022-09-14 16:53:29');